@@ -30,7 +30,7 @@ from ht.conv_tube_bank import ESDU_tube_row_correction
 
 
 
-__all__ = ['Ft_aircooler', 'air_cooler_noise_GPSA', 
+__all__ = ['Ft_aircooler', 'air_cooler_noise_GPSA',
            'air_cooler_noise_Mukherjee', 'h_Briggs_Young',
            'h_ESDU_high_fin', 'h_ESDU_low_fin', 'h_Ganguli_VDI', 'dP_ESDU_high_fin',
            'dP_ESDU_low_fin']
@@ -159,7 +159,7 @@ def Ft_aircooler(Thi, Tho, Tci, Tco, Ntp=1, rows=1):
     Examples
     --------
     >>> Ft_aircooler(Thi=125., Tho=45., Tci=25., Tco=95., Ntp=1, rows=4)
-    0.5505093604092706
+    0.550509360409
 
     References
     ----------
@@ -216,20 +216,20 @@ def Ft_aircooler(Thi, Tho, Tci, Tco, Ntp=1, rows=1):
 
 
 def air_cooler_noise_GPSA(tip_speed, power):
-    r'''Calculates the noise generated by an air cooler bay with one fan 
-    according to the GPSA handbook [1]_.    
+    r'''Calculates the noise generated by an air cooler bay with one fan
+    according to the GPSA handbook [1]_.
 
     .. math::
         \text{PWL[dB(A)]} = 56 + 30\log_{10}\left( \frac{\text{tip speed}
         [m/min]}{304.8 [m/min]}\right) + 10\log_{10}( \text{power}[hp])
-    
+
     Parameters
     ----------
     tip_speed : float
         Tip speed of the air cooler fan blades, [m/s]
     power : float
         Shaft power of single fan motor, [W]
-        
+
     Returns
     -------
     noise : float
@@ -237,33 +237,33 @@ def air_cooler_noise_GPSA(tip_speed, power):
 
     Notes
     -----
-    Internal units are in m/minute, and hp. 
+    Internal units are in m/minute, and hp.
 
     Examples
     --------
     Example problem from GPSA [1]_.
-    
+
     >>> air_cooler_noise_GPSA(tip_speed=3177/minute, power=25.1*hp)
-    100.53680477959792
+    100.5368047795
 
     References
     ----------
-    .. [1] GPSA. "Engineering Data Book, SI." 13th edition. Gas Processors 
+    .. [1] GPSA. "Engineering Data Book, SI." 13th edition. Gas Processors
        Suppliers Association (2012).
     '''
     tip_speed = tip_speed*minute # convert tip speed to m/minute
-    power = power/hp # convert power from W to hp 
+    power = power/hp # convert power from W to hp
     return 56.0 + 30.0*log10(tip_speed/304.8) + 10.0*log10(power)
 
 
 def air_cooler_noise_Mukherjee(tip_speed, power, fan_diameter, induced=False):
-    r'''Calculates the noise generated by an air cooler bay with one fan 
-    according to [1]_.    
+    r'''Calculates the noise generated by an air cooler bay with one fan
+    according to [1]_.
 
     .. math::
-        \text{SPL[dB(A)]} = 46 + 30\log_{10}\text{(tip speed)}[m/s] 
-        + 10\log_{10}( \text{power}[hp]) - 20 \log10(D_{fan})
-    
+        \text{SPL[dB(A)]} = 46 + 30\log_{10}\text{(tip speed)}[m/s]
+        + 10\log_{10}( \text{power}[hp]) - 20 \log_{10}(D_{fan})
+
     Parameters
     ----------
     tip_speed : float
@@ -283,13 +283,13 @@ def air_cooler_noise_Mukherjee(tip_speed, power, fan_diameter, induced=False):
     Notes
     -----
     Internal units are in m/minute, hp, and m.
-    
+
     If the air cooler is induced, the sound pressure level is reduced by 3 dB.
 
     Examples
-    --------    
+    --------
     >>> air_cooler_noise_Mukherjee(tip_speed=3177/minute, power=25.1*hp, fan_diameter=4.267)
-    99.11026329092925
+    99.1102632909
 
     References
     ----------
@@ -303,17 +303,17 @@ def air_cooler_noise_Mukherjee(tip_speed, power, fan_diameter, induced=False):
     return noise
 
 
-def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing, 
-                   tube_diameter, fin_diameter, fin_thickness, bare_length, 
+def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing,
+                   tube_diameter, fin_diameter, fin_thickness, bare_length,
                    rho, Cp, mu, k, k_fin):
     r'''Calculates the air side heat transfer coefficient for an air cooler
-    or other finned tube bundle with the formulas of Briggs and Young [1], [2]_
-    [3]_.
-    
+    or other finned tube bundle with the formulas of Briggs and Young [1]_,
+    [2]_ [3]_.
+
     .. math::
         Nu = 0.134Re^{0.681} Pr^{0.33}\left(\frac{S}{h}\right)^{0.2}
         \left(\frac{S}{b}\right)^{0.1134}
-        
+
     Parameters
     ----------
     m : float
@@ -338,7 +338,7 @@ def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing,
     fin_thickness : float
         Thickness of the fins, [m]
     bare_length : float
-        Length of bare tube between two fins 
+        Length of bare tube between two fins
         :math:`\text{bare length} = \text{fin interval} - t_{fin}`, [m]
     rho : float
         Average (bulk) density of air across the tube bank, [kg/m^3]
@@ -347,38 +347,38 @@ def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing,
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
     k : float
-        Average (bulk) thermal conductivity of air across the tube bank, 
+        Average (bulk) thermal conductivity of air across the tube bank,
         [W/m/K]
     k_fin : float
         Thermal conductivity of the fin, [W/m/K]
-        
+
     Returns
     -------
     h_bare_tube_basis : float
-        Air side heat transfer coefficient on a bare-tube surface area as if 
+        Air side heat transfer coefficient on a bare-tube surface area as if
         there were no fins present basis, [W/K/m^2]
 
     Notes
     -----
-    The limits on this equation are :math:`1000 < Re < `8000`, 
-    11.13 mm :math:`< D_o < ` 40.89 mm, 1.42 mm < fin height < 16.57 mm,
-    0.33 mm < fin thickness < 2.02 mm, 1.30 mm < fin pitch < 4.06 mm, and 
+    The limits on this equation are 1000 < Re < 8000 ,
+    11.13 mm < D_o < 40.89 mm, 1.42 mm < fin height < 16.57 mm,
+    0.33 mm < fin thickness < 2.02 mm, 1.30 mm < fin pitch < 4.06 mm, and
     24.49 mm < normal pitch < 111 mm.
-    
+
     Examples
     --------
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=20, tube_length=3, 
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=20, tube_length=3,
     ... tube_diameter=1*inch, fin_thickness=0.000406, fin_density=1/0.002309,
     ... pitch_normal=.06033, pitch_parallel=.05207,
     ... fin_height=0.0159, tube_thickness=(.0254-.0186)/2,
     ... bundles_per_bay=1, parallel_bays=1, corbels=True)
-    
+
     >>> h_Briggs_Young(m=21.56, A=AC.A, A_min=AC.A_min, A_increase=AC.A_increase, A_fin=AC.A_fin,
     ... A_tube_showing=AC.A_tube_showing, tube_diameter=AC.tube_diameter,
     ... fin_diameter=AC.fin_diameter, bare_length=AC.bare_length,
     ... fin_thickness=AC.fin_thickness,
     ... rho=1.161, Cp=1007., mu=1.85E-5, k=0.0263, k_fin=205)
-    1422.8722403237716
+    1422.872240323
 
     References
     ----------
@@ -386,17 +386,17 @@ def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing,
        Pressure Drop of Air Flowing across Triangular Banks of Finned Tubes",
        Chemical Engineering Progress Symp., Series 41, No. 59. Chem. Eng. Prog.
        Symp. Series No. 41, "Heat Transfer - Houston".
-    .. [2] Mukherjee, R., and Geoffrey Hewitt. Practical Thermal Design of 
+    .. [2] Mukherjee, R., and Geoffrey Hewitt. Practical Thermal Design of
        Air-Cooled Heat Exchangers. New York: Begell House Publishers Inc.,U.S.,
        2007.
-    .. [3] Kroger, Detlev. Air-Cooled Heat Exchangers and Cooling Towers: 
+    .. [3] Kroger, Detlev. Air-Cooled Heat Exchangers and Cooling Towers:
        Thermal-Flow Performance Evaluation and Design, Vol. 1. Tulsa, Okl:
        PennWell Corp., 2004.
     '''
     fin_height = 0.5*(fin_diameter - tube_diameter)
-    
+
     V_max = m/(A_min*rho)
-    
+
     Re = Reynolds(V=V_max, D=tube_diameter, rho=rho, mu=mu)
     Pr = Prandtl(Cp=Cp, mu=mu, k=k)
 
@@ -407,13 +407,13 @@ def h_Briggs_Young(m, A, A_min, A_increase, A_fin, A_tube_showing,
                                            t_fin=fin_thickness, k_fin=k_fin, h=h)
     h_total_area_basis = (efficiency*A_fin + A_tube_showing)/A*h
     h_bare_tube_basis = h_total_area_basis*A_increase
-        
+
     return h_bare_tube_basis
 
 
-def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing, 
+def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing,
                     tube_diameter, fin_diameter, fin_thickness, bare_length,
-                    pitch_parallel, pitch_normal, tube_rows, 
+                    pitch_parallel, pitch_normal, tube_rows,
                     rho, Cp, mu, k, k_fin, Pr_wall=None):
     r'''Calculates the air side heat transfer coefficient for an air cooler
     or other finned tube bundle with the formulas of [2]_ as presented in [1]_.
@@ -422,10 +422,10 @@ def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing,
         Nu = 0.242 Re^{0.658} \left(\frac{\text{bare length}}
         {\text{fin height}}\right)^{0.297}
         \left(\frac{P_1}{P_2}\right)^{-0.091} P_r^{1/3}\cdot F_1\cdot F_2
-                
+
     .. math::
         h_{A,total} = \frac{\eta A_{fin} + A_{bare, showing}}{A_{total}} h
-        
+
     .. math::
         h_{bare,total} = A_{increase} h_{A,total}
 
@@ -453,7 +453,7 @@ def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing,
     fin_thickness : float
         Thickness of the fins, [m]
     bare_length : float
-        Length of bare tube between two fins 
+        Length of bare tube between two fins
         :math:`\text{bare length} = \text{fin interval} - t_{fin}`, [m]
     pitch_parallel : float
         Distance between tube center along a line parallel to the flow;
@@ -470,56 +470,56 @@ def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing,
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
     k : float
-        Average (bulk) thermal conductivity of air across the tube bank, 
+        Average (bulk) thermal conductivity of air across the tube bank,
         [W/m/K]
     k_fin : float
         Thermal conductivity of the fin, [W/m/K]
     Pr_wall : float, optional
-        Prandtl number at the wall temperature; provide if a correction with  
+        Prandtl number at the wall temperature; provide if a correction with
         the defaults parameters is desired; otherwise apply the correction
         elsewhere, [-]
 
     Returns
     -------
     h_bare_tube_basis : float
-        Air side heat transfer coefficient on a bare-tube surface area as if 
+        Air side heat transfer coefficient on a bare-tube surface area as if
         there were no fins present basis, [W/K/m^2]
 
     Notes
     -----
     The tube-row count correction factor is 1 for four or more rows, 0.92 for
     three rows, 0.84 for two rows, and 0.76 for one row according to [1]_.
-    
+
     The property correction factor can be disabled by not specifying
-    `Pr_wall`. A Prandtl number exponent of 0.26 is recommended in [1]_ for 
+    `Pr_wall`. A Prandtl number exponent of 0.26 is recommended in [1]_ for
     heating and cooling for both liquids and gases.
-    
+
     Examples
     --------
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=20, tube_length=3, 
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=20, tube_length=3,
     ... tube_diameter=1*inch, fin_thickness=0.000406, fin_density=1/0.002309,
     ... pitch_normal=.06033, pitch_parallel=.05207,
     ... fin_height=0.0159, tube_thickness=(.0254-.0186)/2,
     ... bundles_per_bay=1, parallel_bays=1, corbels=True)
-    
+
     >>> h_ESDU_high_fin(m=21.56, A=AC.A, A_min=AC.A_min, A_increase=AC.A_increase, A_fin=AC.A_fin,
     ... A_tube_showing=AC.A_tube_showing, tube_diameter=AC.tube_diameter,
     ... fin_diameter=AC.fin_diameter, bare_length=AC.bare_length,
     ... fin_thickness=AC.fin_thickness, tube_rows=AC.tube_rows,
-    ... pitch_normal=AC.pitch_normal, pitch_parallel=AC.pitch_parallel, 
+    ... pitch_normal=AC.pitch_normal, pitch_parallel=AC.pitch_parallel,
     ... rho=1.161, Cp=1007., mu=1.85E-5, k=0.0263, k_fin=205)
-    1390.888918049757
+    1390.88891804
 
     References
     ----------
     .. [1] Hewitt, G. L. Shires, T. Reg Bott G. F., George L. Shires, and T.
-       R. Bott. Process Heat Transfer. 1st edition. Boca Raton: CRC Press, 
+       R. Bott. Process Heat Transfer. 1st edition. Boca Raton: CRC Press,
        1994.
     .. [2] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for
-       Turbulent Single Phase Gas Flow." ESDU 86022 (October 1, 1986). 
+       Turbulent Single Phase Gas Flow." ESDU 86022 (October 1, 1986).
     .. [3] Rabas, T. J., and J. Taborek. "Survey of Turbulent Forced-Convection
        Heat Transfer and Pressure Drop Characteristics of Low-Finned Tube Banks
-       in Cross Flow."  Heat Transfer Engineering 8, no. 2 (January 1987): 
+       in Cross Flow."  Heat Transfer Engineering 8, no. 2 (January 1987):
        49-62.
     '''
     fin_height = 0.5*(fin_diameter - tube_diameter)
@@ -540,8 +540,8 @@ def h_ESDU_high_fin(m, A, A_min, A_increase, A_fin, A_tube_showing,
 
     Nu *= F2
     if Pr_wall is not None:
-        F1 = wall_factor(Pr=Pr, Pr_wall=Pr_wall, Pr_heating_coeff=0.26, 
-                         Pr_cooling_coeff=0.26, 
+        F1 = wall_factor(Pr=Pr, Pr_wall=Pr_wall, Pr_heating_coeff=0.26,
+                         Pr_cooling_coeff=0.26,
                          property_option=WALL_FACTOR_PRANDTL)
         Nu *= F1
 
@@ -562,19 +562,19 @@ def h_ESDU_low_fin(m, A, A_min, A_increase, A_fin,
     r'''Calculates the air side heat transfer coefficient for an air cooler
     or other finned tube bundle with low fins using the formulas of [1]_ as
     presented in [2]_ (and also [3]_).
-    
+
     .. math::
         Nu = 0.183Re^{0.7} \left(\frac{\text{bare length}}{\text{fin height}}
         \right)^{0.36}\left(\frac{p_1}{D_{o}}\right)^{0.06}
         \left(\frac{\text{fin height}}{D_o}\right)^{0.11}
         Pr^{0.36} \cdot F_1\cdot F_2
-        
+
     .. math::
         h_{A,total} = \frac{\eta A_{fin} + A_{bare, showing}}{A_{total}} h
-        
+
     .. math::
         h_{bare,total} = A_{increase} h_{A,total}
-        
+
     Parameters
     ----------
     m : float
@@ -599,7 +599,7 @@ def h_ESDU_low_fin(m, A, A_min, A_increase, A_fin,
     fin_thickness : float
         Thickness of the fins, [m]
     bare_length : float
-        Length of bare tube between two fins 
+        Length of bare tube between two fins
         :math:`\text{bare length} = \text{fin interval} - t_{fin}`, [m]
     pitch_parallel : float
         Distance between tube center along a line parallel to the flow;
@@ -616,58 +616,58 @@ def h_ESDU_low_fin(m, A, A_min, A_increase, A_fin,
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
     k : float
-        Average (bulk) thermal conductivity of air across the tube bank, 
+        Average (bulk) thermal conductivity of air across the tube bank,
         [W/m/K]
     k_fin : float
         Thermal conductivity of the fin, [W/m/K]
     Pr_wall : float, optional
-        Prandtl number at the wall temperature; provide if a correction with  
+        Prandtl number at the wall temperature; provide if a correction with
         the defaults parameters is desired; otherwise apply the correction
         elsewhere, [-]
-        
+
     Returns
     -------
     h_bare_tube_basis : float
-        Air side heat transfer coefficient on a bare-tube surface area as if 
+        Air side heat transfer coefficient on a bare-tube surface area as if
         there were no fins present basis, [W/K/m^2]
 
     Notes
     -----
     The tube-row count correction factor `F2` can be disabled by setting `tube_rows`
     to 10. The property correction factor `F1` can be disabled by not specifying
-    `Pr_wall`. A Prandtl number exponent of 0.26 is recommended in [1]_ for 
+    `Pr_wall`. A Prandtl number exponent of 0.26 is recommended in [1]_ for
     heating and cooling for both liquids and gases.
-    
+
     There is a third correction factor in [1]_ for tube angles not 30, 45, or
-    60 degrees, but it is not fully explained and it is not shown in [2]_. 
+    60 degrees, but it is not fully explained and it is not shown in [2]_.
     Another correction factor is in [2]_ for flow at an angle; however it would
     not make sense to apply it to finned tube banks due to the blockage by the
     fins.
-    
+
     Examples
     --------
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5, 
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5,
     ... tube_diameter=0.0164, fin_thickness=0.001, fin_density=1/0.003,
     ... pitch_normal=0.0313, pitch_parallel=0.0271, fin_height=0.0041, corbels=True)
-    
+
     >>> h_ESDU_low_fin(m=0.914, A=AC.A, A_min=AC.A_min, A_increase=AC.A_increase, A_fin=AC.A_fin,
     ... A_tube_showing=AC.A_tube_showing, tube_diameter=AC.tube_diameter,
     ... fin_diameter=AC.fin_diameter, bare_length=AC.bare_length,
     ... fin_thickness=AC.fin_thickness, tube_rows=AC.tube_rows,
-    ... pitch_normal=AC.pitch_normal, pitch_parallel=AC.pitch_parallel, 
+    ... pitch_normal=AC.pitch_normal, pitch_parallel=AC.pitch_parallel,
     ... rho=1.217, Cp=1007., mu=1.8E-5, k=0.0253, k_fin=15)
-    553.853836470948
+    553.85383647
 
     References
     ----------
     .. [1] Hewitt, G. L. Shires, T. Reg Bott G. F., George L. Shires, and T.
-       R. Bott. Process Heat Transfer. 1st edition. Boca Raton: CRC Press, 
+       R. Bott. Process Heat Transfer. 1st edition. Boca Raton: CRC Press,
        1994.
     .. [2] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for
-       Turbulent Single Phase Gas Flow." ESDU 86022 (October 1, 1986). 
+       Turbulent Single Phase Gas Flow." ESDU 86022 (October 1, 1986).
     .. [3] Rabas, T. J., and J. Taborek. "Survey of Turbulent Forced-Convection
        Heat Transfer and Pressure Drop Characteristics of Low-Finned Tube Banks
-       in Cross Flow."  Heat Transfer Engineering 8, no. 2 (January 1987): 
+       in Cross Flow."  Heat Transfer Engineering 8, no. 2 (January 1987):
        49-62.
     '''
     fin_height = 0.5*(fin_diameter - tube_diameter)
@@ -678,20 +678,20 @@ def h_ESDU_low_fin(m, A, A_min, A_increase, A_fin,
     Nu = (0.183*Re**0.7*(bare_length/fin_height)**0.36
           *(pitch_normal/fin_diameter)**0.06
           *(fin_height/fin_diameter)**0.11*Pr**0.36)
-    
+
     staggered = abs(1 - pitch_normal/pitch_parallel) > 0.05
     F2 = ESDU_tube_row_correction(tube_rows=tube_rows, staggered=staggered)
     Nu *= F2
     if Pr_wall is not None:
-        F1 = wall_factor(Pr=Pr, Pr_wall=Pr_wall, Pr_heating_coeff=0.26, 
-                         Pr_cooling_coeff=0.26, 
+        F1 = wall_factor(Pr=Pr, Pr_wall=Pr_wall, Pr_heating_coeff=0.26,
+                         Pr_cooling_coeff=0.26,
                          property_option=WALL_FACTOR_PRANDTL)
         Nu *= F1
-    
+
     h = k/tube_diameter*Nu
-    efficiency = fin_efficiency_Kern_Kraus(Do=tube_diameter, 
-                                           D_fin=fin_diameter, 
-                                           t_fin=fin_thickness, 
+    efficiency = fin_efficiency_Kern_Kraus(Do=tube_diameter,
+                                           D_fin=fin_diameter,
+                                           t_fin=fin_thickness,
                                            k_fin=k_fin, h=h)
     h_total_area_basis = (efficiency*A_fin + A_tube_showing)/A*h
     h_bare_tube_basis = h_total_area_basis*A_increase
@@ -705,17 +705,17 @@ def h_Ganguli_VDI(m, A, A_min, A_increase, A_fin,
                   rho, Cp, mu, k, k_fin):
     r'''Calculates the air side heat transfer coefficient for an air cooler
     or other finned tube bundle with the formulas of [1]_ as modified in [2]_.
-    
+
     Inline:
-        
+
     .. math::
         Nu_d = 0.22Re_d^{0.6}\left(\frac{A}{A_{tube,only}}\right)^{-0.15}Pr^{1/3}
-        
+
     Staggered:
-        
+
     .. math::
         Nu_d = 0.38 Re_d^{0.6}\left(\frac{A}{A_{tube,only}}\right)^{-0.15}Pr^{1/3}
-            
+
     Parameters
     ----------
     m : float
@@ -740,7 +740,7 @@ def h_Ganguli_VDI(m, A, A_min, A_increase, A_fin,
     fin_thickness : float
         Thickness of the fins, [m]
     bare_length : float
-        Length of bare tube between two fins 
+        Length of bare tube between two fins
         :math:`\text{bare length} = \text{fin interval} - t_{fin}`, [m]
     pitch_parallel : float
         Distance between tube center along a line parallel to the flow;
@@ -757,34 +757,34 @@ def h_Ganguli_VDI(m, A, A_min, A_increase, A_fin,
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
     k : float
-        Average (bulk) thermal conductivity of air across the tube bank, 
+        Average (bulk) thermal conductivity of air across the tube bank,
         [W/m/K]
     k_fin : float
         Thermal conductivity of the fin, [W/m/K]
-        
+
     Returns
     -------
     h_bare_tube_basis : float
-        Air side heat transfer coefficient on a bare-tube surface area as if 
+        Air side heat transfer coefficient on a bare-tube surface area as if
         there were no fins present basis, [W/K/m^2]
 
     Notes
     -----
     The VDI modifications were developed in comparison with HTFS and HTRI data
     according to [2]_.
-    
+
     For cases where the tube row count is less than four, the coefficients are
     modified in [2]_. For the inline case, 0.2 replaces 0.22. For the stagered
-    cases, the coefficient is 0.2, 0.33, 0.36 for 1, 2, or 3 tube rows 
+    cases, the coefficient is 0.2, 0.33, 0.36 for 1, 2, or 3 tube rows
     respectively.
-    
+
     The model is also showin in [4]_.
-    
+
     Examples
     --------
     Example 12.1 in [3]_:
-    
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=56, tube_length=36*foot, 
+
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=56, tube_length=36*foot,
     ... tube_diameter=1*inch, fin_thickness=0.013*inch, fin_density=10/inch,
     ... angle=30, pitch_normal=2.5*inch, fin_height=0.625*inch, corbels=True)
 
@@ -794,18 +794,18 @@ def h_Ganguli_VDI(m, A, A_min, A_increase, A_fin,
     ... fin_thickness=AC.fin_thickness, tube_rows=AC.tube_rows,
     ... pitch_parallel=AC.pitch_parallel, pitch_normal=AC.pitch_normal,
     ... rho=1.2013848, Cp=1009.0188, mu=1.9304793e-05, k=0.027864828, k_fin=238)
-    969.2850818578595
-    
+    969.285081857
+
     References
     ----------
     .. [1] Ganguli, A., S. S. Tung, and J. Taborek. "Parametric Study of
-       Air-Cooled Heat Exchanger Finned Tube Geometry." In AIChE Symposium 
+       Air-Cooled Heat Exchanger Finned Tube Geometry." In AIChE Symposium
        Series, 81:122-28, 1985.
     .. [2] Gesellschaft, V. D. I., ed. VDI Heat Atlas. 2nd edition.
        Berlin; New York:: Springer, 2010.
-    .. [3] Serth, Robert W., and Thomas Lestina. Process Heat Transfer: 
+    .. [3] Serth, Robert W., and Thomas Lestina. Process Heat Transfer:
        Principles, Applications and Rules of Thumb. Academic Press, 2014.
-    .. [4] Kroger, Detlev. Air-Cooled Heat Exchangers and Cooling Towers: 
+    .. [4] Kroger, Detlev. Air-Cooled Heat Exchangers and Cooling Towers:
        Thermal-Flow Performance Evaluation and Design, Vol. 1. Tulsa, Okl:
        PennWell Corp., 2004.
     '''
@@ -841,12 +841,12 @@ def h_Ganguli_VDI(m, A, A_min, A_increase, A_fin,
 
 
 def dP_ESDU_high_fin(m, A_min, A_increase, flow_area_contraction_ratio,
-                     tube_diameter, pitch_parallel, pitch_normal, tube_rows, 
+                     tube_diameter, pitch_parallel, pitch_normal, tube_rows,
                      rho, mu):
     r'''Calculates the air-side pressure drop for a high-finned tube bank
     according to the ESDU [1]_ method, as described in [2]_. This includes the
     effects of friction of the fin, and acceleration.
- 
+
     .. math::
         \Delta P = (K_{acc} + n_{rows} K_{f}) \frac{1}{2}\rho v_{max}^2
 
@@ -857,7 +857,7 @@ def dP_ESDU_high_fin(m, A_min, A_increase, flow_area_contraction_ratio,
 
     .. math::
         K_{acc} = 1 + \text{(flow area contraction ratio)}^2
-            
+
     Parameters
     ----------
     m : float
@@ -883,7 +883,7 @@ def dP_ESDU_high_fin(m, A_min, A_increase, flow_area_contraction_ratio,
         Average (bulk) density of air across the tube bank, [kg/m^3]
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
-        
+
     Returns
     -------
     dP : float
@@ -897,26 +897,26 @@ def dP_ESDU_high_fin(m, A_min, A_increase, flow_area_contraction_ratio,
         * fin heights 1/3 to 5/8 inches
         * fin tip to fin root diameters 1.2 to 2.4
         * Reynolds numbers 5000 to 50000
-        
-    [1]_ claims 72% of experimental points were within 10% of the results of 
-    the correlation.    
-    
-    The Reynolds number used in this equation is that based on `V_max`, 
+
+    [1]_ claims 72% of experimental points were within 10% of the results of
+    the correlation.
+
+    The Reynolds number used in this equation is that based on `V_max`,
     calculated using the minimum flow area.
-    
+
     Examples
     --------
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5, 
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5,
     ... tube_diameter=0.0164, fin_thickness=0.001, fin_density=1/0.003,
     ... pitch_normal=0.0313, pitch_parallel=0.0271, fin_height=0.0041, corbels=True)
 
     >>> dP_ESDU_high_fin(m=0.914, A_min=AC.A_min, A_increase=AC.A_increase, flow_area_contraction_ratio=AC.flow_area_contraction_ratio, tube_diameter=AC.tube_diameter, pitch_parallel=AC.pitch_parallel, pitch_normal=AC.pitch_normal, tube_rows=AC.tube_rows, rho=1.217,  mu=0.000018)
-    485.6307687791502
-    
+    485.630768779
+
     References
     ----------
-    .. [1] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for 
-       Turbulent Single Phase Gas Flow." ESDU (October 1, 1986). 
+    .. [1] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for
+       Turbulent Single Phase Gas Flow." ESDU (October 1, 1986).
     .. [2] Hewitt, G. L. Shires T. Reg Bott G. F., George L. Shires, and
        T. R. Bott. Process Heat Transfer. 1E. Boca Raton: CRC Press, 1994.
     '''
@@ -931,12 +931,12 @@ def dP_ESDU_high_fin(m, A_min, A_increase, flow_area_contraction_ratio,
 
 
 def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
-                    tube_diameter, fin_height, bare_length, pitch_parallel, 
+                    tube_diameter, fin_height, bare_length, pitch_parallel,
                     pitch_normal, tube_rows, rho, mu):
     r'''Calculates the air-side pressure drop for a low-finned tube bank
     according to the ESDU [1]_ method, as described in [2]_. This includes the
     effects of friction of the fin, and acceleration.
- 
+
     .. math::
         \Delta P = (K_{acc} + n_{rows} K_{f}) \frac{1}{2}\rho v_{max}^2
 
@@ -945,10 +945,10 @@ def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
         {\text{bare length}}\right)^{0.51}
         \left(\frac{p_1 - D_o}{p_2 - D_o}\right)^{0.536}
         \left(\frac{D_o}{p_1 - D_o}\right)^{0.36}
-        
+
     .. math::
         K_{acc} = 1 + \text{(flow area contraction ratio)}^2
-            
+
     Parameters
     ----------
     m : float
@@ -965,7 +965,7 @@ def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
     fin_height : float
         Height above bare tube of the tube fins, [m]
     bare_length : float
-        Length of bare tube between two fins 
+        Length of bare tube between two fins
         :math:`\text{bare length} = \text{fin interval} - t_{fin}`, [m]
     pitch_parallel : float
         Distance between tube center along a line parallel to the flow;
@@ -979,7 +979,7 @@ def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
         Average (bulk) density of air across the tube bank, [kg/m^3]
     mu : float
         Average (bulk) viscosity of air across the tube bank, [Pa*s]
-        
+
     Returns
     -------
     dP : float
@@ -989,35 +989,36 @@ def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
     -----
     Low fins are fins which were formed on the tube outside wall, normally
     by the cold rolling process. The data used by the ESDU covered:
-        * fin density 11 to 32/inch
-        * tube outer diameters 0.5 to 1.25 inches
-        * fin heights 0.03 to 0.1 inches
-        * Reynolds numbers 1000 to 80000
-        
+
+    * fin density 11 to 32/inch
+    * tube outer diameters 0.5 to 1.25 inches
+    * fin heights 0.03 to 0.1 inches
+    * Reynolds numbers 1000 to 80000
+
     [1]_ compared this correlation with 81 results and obtained a standard
-    deviation of 7.7%. 
-    
-    The Reynolds number used in this equation is that based on `V_max`, 
+    deviation of 7.7%.
+
+    The Reynolds number used in this equation is that based on `V_max`,
     calculated using the minimum flow area.
-    
+
     Examples
     --------
-    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5, 
+    >>> AC = AirCooledExchanger(tube_rows=4, tube_passes=4, tubes_per_row=8, tube_length=0.5,
     ... tube_diameter=0.0164, fin_thickness=0.001, fin_density=1/0.003,
     ... pitch_normal=0.0313, pitch_parallel=0.0271, fin_height=0.0041, corbels=True)
 
-    >>> dP_ESDU_low_fin(m=0.914, A_min=AC.A_min, A_increase=AC.A_increase, 
+    >>> dP_ESDU_low_fin(m=0.914, A_min=AC.A_min, A_increase=AC.A_increase,
     ... flow_area_contraction_ratio=AC.flow_area_contraction_ratio,
-    ... tube_diameter=AC.tube_diameter, fin_height=AC.fin_height, 
-    ... bare_length=AC.bare_length, pitch_parallel=AC.pitch_parallel, 
-    ... pitch_normal=AC.pitch_normal, tube_rows=AC.tube_rows, rho=1.217, 
+    ... tube_diameter=AC.tube_diameter, fin_height=AC.fin_height,
+    ... bare_length=AC.bare_length, pitch_parallel=AC.pitch_parallel,
+    ... pitch_normal=AC.pitch_normal, tube_rows=AC.tube_rows, rho=1.217,
     ... mu=0.000018)
-    464.54331418655914
-    
+    464.5433141865
+
     References
     ----------
-    .. [1] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for 
-       Turbulent Single Phase Gas Flow." ESDU (October 1, 1986). 
+    .. [1] "High-Fin Staggered Tube Banks: Heat Transfer and Pressure Drop for
+       Turbulent Single Phase Gas Flow." ESDU (October 1, 1986).
     .. [2] Hewitt, G. L. Shires T. Reg Bott G. F., George L. Shires, and
        T. R. Bott. Process Heat Transfer. 1E. Boca Raton: CRC Press, 1994.
     '''
@@ -1031,7 +1032,7 @@ def dP_ESDU_low_fin(m, A_min, A_increase, flow_area_contraction_ratio,
     return dP
 
 
-'''Three more correlations - 
+'''Three more correlations -
 
 Heat Transfer and Pressure Drop Characteristics of Dry Tower Extended Surfaces: Data Analysis and Correlation. Pacific Northwest Laboratory, 1976.
 * said to be in common use in http://www.thermopedia.com/content/551/
