@@ -28,14 +28,14 @@ __all__ = ['Nu_cylinder_Zukauskas', 'Nu_cylinder_Churchill_Bernstein',
            'Nu_cylinder_Perkins_Leppert_1964',
            'Nu_cylinder_Perkins_Leppert_1962', 'Nu_cylinder_Whitaker',
            'Nu_cylinder_McAdams',
-           'conv_external_cylinder_methods', 'Nu_external_cylinder',
-           'Nu_horizontal_plate_laminar_Baehr', 
+           'Nu_external_cylinder',
+           'Nu_external_cylinder_methods',
+           'Nu_horizontal_plate_laminar_Baehr',
            'Nu_horizontal_plate_laminar_Churchill_Ozoe',
            'Nu_horizontal_plate_turbulent_Schlichting',
            'Nu_horizontal_plate_turbulent_Kreith',
            'Nu_external_horizontal_plate',
-           
-           'conv_horizontal_plate_laminar_methods', 'conv_horizontal_plate_turbulent_methods',
+           'Nu_external_horizontal_plate_methods',
            'LAMINAR_TRANSITION_HORIZONTAL_PLATE', 'conv_horizontal_plate_methods',
            ]
 
@@ -115,7 +115,7 @@ def Nu_cylinder_Zukauskas(Re, Pr, Prw=None):
     else:
         n = 0.36
     Nu = c*Re**m*Pr**n
-    if Prw:
+    if Prw is not None:
         Nu = Nu*(Pr/Prw)**0.25
     return Nu
 
@@ -363,7 +363,7 @@ def Nu_cylinder_Whitaker(Re, Pr, mu=None, muw=None):
        doi:10.1016/j.ijheatmasstransfer.2004.05.012.
     '''
     Nu = (0.4*Re**0.5 + 0.06*Re**(2/3.))*Pr**0.3
-    if mu and muw:
+    if mu is not None and muw is not None:
         Nu *= (mu/muw)**0.25
     return Nu
 
@@ -417,7 +417,7 @@ def Nu_cylinder_Perkins_Leppert_1962(Re, Pr, mu=None, muw=None):
        doi:10.1016/j.ijheatmasstransfer.2004.05.012.
     '''
     Nu = (0.30*Re**0.5 + 0.10*Re**0.67)*Pr**0.4
-    if mu and muw:
+    if mu is not None and muw is not None:
         Nu *= (mu/muw)**0.25
     return Nu
 
@@ -473,7 +473,7 @@ def Nu_cylinder_Perkins_Leppert_1964(Re, Pr, mu=None, muw=None):
        doi:10.1016/j.ijheatmasstransfer.2004.05.012.
     '''
     Nu = (0.31*Re**0.5 + 0.11*Re**0.67)*Pr**0.4
-    if mu and muw:
+    if mu is not None and muw is not None:
         Nu *= (mu/muw)**0.25
     return Nu
 
@@ -489,25 +489,68 @@ conv_external_cylinder_turbulent_methods = {
     'Perkins-Leppert 1964': (Nu_cylinder_Perkins_Leppert_1964, ('Re', 'Pr', 'mu', 'muw')),
 }
 
-conv_external_cylinder_turbulent_methods_ranked = ['Sanitjai-Goldstein', 
-                                                   'Churchill-Bernstein', 
-                                                   'Zukauskas', 'Whitaker', 
-                                                   'Perkins-Leppert 1964',  
-                                                   'McAdams',  'Fand', 
+conv_external_cylinder_turbulent_methods_ranked = ['Sanitjai-Goldstein',
+                                                   'Churchill-Bernstein',
+                                                   'Zukauskas', 'Whitaker',
+                                                   'Perkins-Leppert 1964',
+                                                   'McAdams',  'Fand',
                                                    'Perkins-Leppert 1962']
 
 conv_external_cylinder_methods = conv_external_cylinder_turbulent_methods.copy()
 
+_missing_external_cylinder_method = "Correlation name not recognized; the availble methods are %s." %(list(conv_external_cylinder_methods.keys()))
 
-def Nu_external_cylinder(Re, Pr, Prw=None, mu=None, muw=None, Method=None, 
-                         AvailableMethods=False):
-    r'''Calculates Nusselt number for crossflow across a single tube at a 
+
+def Nu_external_cylinder_methods(Re, Pr, Prw=None, mu=None, muw=None, check_ranges=True):
+    r'''This function returns a list of correlation names for forced convection
+    over an external cylinder.
+
+    The preferred method 'Sanitjai-Goldstein'.
+
+    Parameters
+    ----------
+    Re : float
+        Reynolds number of fluid with respect to cylinder diameter, [-]
+    Pr : float
+        Prandtl number at either the free stream or wall temperature
+        depending on the method, [-]
+    Prw : float, optional
+        Prandtl number at wall temperature, [-]
+    mu : float, optional
+        Viscosity of fluid at the free stream temperature [Pa*s]
+    muw : float, optional
+        Viscosity of fluid at the wall temperature [Pa*s]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs
+
+    Examples
+    --------
+    >>> Nu_external_cylinder_methods(0.72, 1E7)[0]
+    'Sanitjai-Goldstein'
+    '''
+    methods = ['Sanitjai-Goldstein', 'Churchill-Bernstein', 'Fand', 'McAdams']
+    if Prw is not None:
+        methods.append('Zukauskas')
+    if mu is not None and muw is not None:
+        methods.extend(['Whitaker', 'Perkins-Leppert 1964', 'Perkins-Leppert 1962'])
+    return methods
+
+
+def Nu_external_cylinder(Re, Pr, Prw=None, mu=None, muw=None, Method=None):
+    r'''Calculates Nusselt number for crossflow across a single tube at a
     specified `Re` and `Pr` according to the specified method. Optional
     parameters are `Prw`, `mu`, and `muw`. This function has eight methods
     available. The 'Sanitjai-Goldstein' method is
     the default.
-    
-    The front of the cyliner is normally always in a laminar regime; whereas 
+
+    The front of the cyliner is normally always in a laminar regime; whereas
     the back is turbulent. The proportions change with `Re`; all correlations
     take this into account. For this heat transfer case, there is no separation
     between laminar and turbulent methods.
@@ -517,7 +560,7 @@ def Nu_external_cylinder(Re, Pr, Prw=None, mu=None, muw=None, Method=None,
     Re : float
         Reynolds number of fluid with respect to cylinder diameter, [-]
     Pr : float
-        Prandtl number at either the free stream or wall temperature 
+        Prandtl number at either the free stream or wall temperature
         depending on the method, [-]
     Prw : float, optional
         Prandtl number at wall temperature, [-]
@@ -536,16 +579,12 @@ def Nu_external_cylinder(Re, Pr, Prw=None, mu=None, muw=None, Method=None,
     Method : string, optional
         A string of the function name to use, as in the dictionary
         conv_external_cylinder_methods.
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate the Nusselt number with the given inputs and return
-        them as a list instead of performing a calculation.
 
     Notes
     -----
     A comparison of the methods for various Prandtl and Reynolds number ranges
     is plotted below.
-    
+
     .. plot:: plots/Nu_external_cylinder.py
 
     Examples
@@ -553,57 +592,57 @@ def Nu_external_cylinder(Re, Pr, Prw=None, mu=None, muw=None, Method=None,
     >>> Nu_external_cylinder(6071, 0.7)
     40.38327083519522
     '''
-    def list_methods():
-        methods = []
-        methods.extend(conv_external_cylinder_turbulent_methods_ranked)
-        return methods
-    
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
+    Method2 = 'Sanitjai-Goldstein' if Method is None else Method
 
-    if Method in conv_external_cylinder_methods:
-        f, args = conv_external_cylinder_methods[Method]
-        
-        kwargs = {}
-        for arg in args:
-            kwargs[arg] = locals()[arg]
-        return f(**kwargs)
+    if Method2 == 'Sanitjai-Goldstein':
+        return Nu_cylinder_Sanitjai_Goldstein(Re=Re, Pr=Pr)
+    elif Method2 == 'Churchill-Bernstein':
+        return Nu_cylinder_Sanitjai_Goldstein(Re=Re, Pr=Pr)
+    elif Method2 == 'Fand':
+        return Nu_cylinder_Fand(Re=Re, Pr=Pr)
+    elif Method2 == 'McAdams':
+        return Nu_cylinder_McAdams(Re=Re, Pr=Pr)
+
+    elif Method2 == 'Zukauskas':
+        return Nu_cylinder_Zukauskas(Re=Re, Pr=Pr, Prw=Prw)
+    elif Method2 == 'Whitaker':
+        return Nu_cylinder_Whitaker(Re=Re, Pr=Pr, mu=mu, muw=muw)
+    elif Method2 == 'Perkins-Leppert 1962':
+        return Nu_cylinder_Perkins_Leppert_1962(Re=Re, Pr=Pr, mu=mu, muw=muw)
+    elif Method2 == 'Perkins-Leppert 1964':
+        return Nu_cylinder_Perkins_Leppert_1964(Re=Re, Pr=Pr, mu=mu, muw=muw)
     else:
-        raise Exception("Correlation name not recognized; the availble methods "
-                        "are %s." %(list(conv_external_cylinder_methods.keys())))
-    return Nu
 
+        raise ValueError(_missing_external_cylinder_method)
 
 # Horizontal Plate in crossflow
 
 def Nu_horizontal_plate_laminar_Baehr(Re, Pr):
-    r'''Calculates Nusselt number for laminar flow across an **isothermal**  
-    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk 
-    temperature. No other wall correction is necessary for this formulation. 
+    r'''Calculates Nusselt number for laminar flow across an **isothermal**
+    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk
+    temperature. No other wall correction is necessary for this formulation.
     Four different equations are used for different Prandtl number ranges.
-    
+
     The equation for the common Prandtl number range is also recommended in
     [2]_ and [3]_.
-    
+
     if :math:`\text{Pr} < 0.005`:
-        
+
     .. math::
         \text{Nu}_L = 1.128\text{Re}^{0.5}\text{Pr}^{0.5}
-        
+
     if :math:`0.005 < \text{Pr} < 0.05`:
-        
+
     .. math::
         \text{Nu}_L = 1.0\text{Re}^{0.5}\text{Pr}^{0.5}
-        
+
     if :math:`0.6 < \text{Pr} < 10`:
-        
+
     .. math::
         \text{Nu}_L = 0.664\text{Re}^{0.5}\text{Pr}^{1/3}
-        
+
     if :math:`\text{Pr} > 10`:
-        
+
     .. math::
         \text{Nu}_L = 0.678\text{Re}^{0.5}\text{Pr}^{1/3}
 
@@ -622,7 +661,7 @@ def Nu_horizontal_plate_laminar_Baehr(Re, Pr):
 
     Notes
     -----
-    Does not take into account the impact of free convection, which can 
+    Does not take into account the impact of free convection, which can
     increase the convection substantially.
 
     Examples
@@ -652,14 +691,14 @@ def Nu_horizontal_plate_laminar_Baehr(Re, Pr):
 
 
 def Nu_horizontal_plate_laminar_Churchill_Ozoe(Re, Pr):
-    r'''Calculates Nusselt number for laminar flow across an **isothermal**  
-    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk 
-    temperature. No other wall correction is necessary for this formulation. 
+    r'''Calculates Nusselt number for laminar flow across an **isothermal**
+    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk
+    temperature. No other wall correction is necessary for this formulation.
     A single equation covers all Prandtl number ranges.
-        
+
     .. math::
         Nu_L = \frac{0.6774Re_L^{1/2}Pr^{1/3}}{[1+(0.0468/Pr)^{2/3}]^{1/4}}
-        
+
 
     Parameters
     ----------
@@ -676,7 +715,7 @@ def Nu_horizontal_plate_laminar_Churchill_Ozoe(Re, Pr):
 
     Notes
     -----
-    Does not take into account the impact of free convection, which can 
+    Does not take into account the impact of free convection, which can
     increase the convection substantially.
 
     Examples
@@ -686,8 +725,8 @@ def Nu_horizontal_plate_laminar_Churchill_Ozoe(Re, Pr):
 
     References
     ----------
-    .. [1] Churchill, Stuart W., and Hiroyuki Ozoe. "Correlations for Laminar 
-       Forced Convection in Flow Over an Isothermal Flat Plate and in 
+    .. [1] Churchill, Stuart W., and Hiroyuki Ozoe. "Correlations for Laminar
+       Forced Convection in Flow Over an Isothermal Flat Plate and in
        Developing and Fully Developed Flow in an Isothermal Tube." Journal of
        Heat Transfer 95, no. 3 (August 1, 1973): 416
        https://doi.org/10.1115/1.3450078.
@@ -700,13 +739,13 @@ def Nu_horizontal_plate_laminar_Churchill_Ozoe(Re, Pr):
 
 
 def Nu_horizontal_plate_turbulent_Schlichting(Re, Pr):
-    r'''Calculates Nusselt number for turbulent flow across an **isothermal**  
-    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk 
-    temperature. The formulation of Schlichting is used, which adds a 
+    r'''Calculates Nusselt number for turbulent flow across an **isothermal**
+    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk
+    temperature. The formulation of Schlichting is used, which adds a
     surface friction term to a formulation from Petukhov and Popov.
-            
+
     .. math::
-        \text{Nu}_L = \frac{0.037\text{Re_L}^{0.8} \text{Pr}}
+        \text{Nu}_L = \frac{0.037\text{Re}_L^{0.8} \text{Pr}}
         {1 + 2.443\text{Re}_L^{-0.1}(\text{Pr}^{2/3} - 1)}
 
     Parameters
@@ -724,7 +763,7 @@ def Nu_horizontal_plate_turbulent_Schlichting(Re, Pr):
 
     Notes
     -----
-    Does not take into account the impact of free convection, which can 
+    Does not take into account the impact of free convection, which can
     increase the convection substantially.
 
     Examples
@@ -734,8 +773,8 @@ def Nu_horizontal_plate_turbulent_Schlichting(Re, Pr):
 
     References
     ----------
-    .. [1] Schlichting, H., and Klaus Gersten. Grenzschicht-Theorie. 9th ed. 
-       Berlin Heidelberg: Springer-Verlag, 1997. 
+    .. [1] Schlichting, H., and Klaus Gersten. Grenzschicht-Theorie. 9th ed.
+       Berlin Heidelberg: Springer-Verlag, 1997.
        http://www.springer.com/de/book/9783662075548.
     .. [2] Gesellschaft, V. D. I., ed. VDI Heat Atlas. 2nd ed. 2010 edition.
        Berlin ; New York: Springer, 2010.
@@ -746,10 +785,10 @@ def Nu_horizontal_plate_turbulent_Schlichting(Re, Pr):
 
 
 def Nu_horizontal_plate_turbulent_Kreith(Re, Pr):
-    r'''Calculates Nusselt number for turbulent flow across an **isothermal**  
-    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk 
+    r'''Calculates Nusselt number for turbulent flow across an **isothermal**
+    flat plate at a specified `Re` and `Pr`, both evaluated at the bulk
     temperature. The formulation of Kreith is used.
-            
+
     .. math::
         \text{Nu}_L = 0.036\text{Re}_L^{0.8} \text{Pr}^{2/3}
 
@@ -768,7 +807,7 @@ def Nu_horizontal_plate_turbulent_Kreith(Re, Pr):
 
     Notes
     -----
-    Does not take into account the impact of free convection, which can 
+    Does not take into account the impact of free convection, which can
     increase the convection substantially. Applies for turbulent flow only.
 
     Examples
@@ -799,22 +838,60 @@ conv_horizontal_plate_methods.update(conv_horizontal_plate_turbulent_methods)
 
 LAMINAR_TRANSITION_HORIZONTAL_PLATE = 5E5
 
+def Nu_external_horizontal_plate_methods(Re, Pr, L=None, x=None,
+                                   check_ranges=True):
+    r'''Returns a list of correlation names for calculating Nusselt number for
+    forced convection across a horizontal plate, supporting both laminar
+    and turbulent regimes.
 
-def Nu_external_horizontal_plate(Re, Pr, L=None, x=None, Method=None, 
+    Parameters
+    ----------
+    Re : float
+        Reynolds number with respect to bulk properties and plate length, [-]
+    Pr : float
+        Prandtl number with respect to bulk properties, [-]
+    L : float, optional
+        Length of horizontal plate, [m]
+    x : float, optional
+        Length of horizontal plate for specific calculation distance, [m]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs
+
+    Examples
+    --------
+    >>> Nu_external_horizontal_plate_methods(Re=1e7, Pr=.7)[0]
+    'Schlichting'
+    '''
+    turbulent = Re >= LAMINAR_TRANSITION_HORIZONTAL_PLATE
+    if check_ranges:
+        if turbulent:
+            return ['Schlichting', 'Kreith']
+        else:
+            return ['Baehr', 'Churchill Ozoe']
+    else:
+        return ['Baehr', 'Churchill Ozoe', 'Schlichting', 'Kreith']
+
+def Nu_external_horizontal_plate(Re, Pr, L=None, x=None, Method=None,
                                  laminar_method='Baehr',
-                                 turbulent_method='Schlichting', 
-                                 Re_transition=LAMINAR_TRANSITION_HORIZONTAL_PLATE,
-                                 AvailableMethods=False):
+                                 turbulent_method='Schlichting',
+                                 Re_transition=LAMINAR_TRANSITION_HORIZONTAL_PLATE):
     r'''This function calculates the heat transfer coefficient for external
-    forced convection along a horizontal plate. 
-    
-    Requires at a minimum a flow's Reynolds and Prandtl numbers `Re` and `Pr`. 
-    `L` and `x` are not used by any correlations presently, but are included 
+    forced convection along a horizontal plate.
+
+    Requires at a minimum a flow's Reynolds and Prandtl numbers `Re` and `Pr`.
+    `L` and `x` are not used by any correlations presently, but are included
     for future support.
-    
-    If no correlation's name is provided as `Method`, the most accurate 
+
+    If no correlation's name is provided as `Method`, the most accurate
     applicable correlation is selected.
-    
+
     Parameters
     ----------
     Re : float
@@ -830,8 +907,6 @@ def Nu_external_horizontal_plate(Re, Pr, L=None, x=None, Method=None,
     -------
     Nu : float
         Nusselt number with respect to plate length, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Nu` with the given inputs
 
     Other Parameters
     ----------------
@@ -845,39 +920,28 @@ def Nu_external_horizontal_plate(Re, Pr, L=None, x=None, Method=None,
     Re_transition : float, optional
         The transition Reynolds number for laminar changing to turbulent flow,
         [-]
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `Nu` with the given inputs
-        
+
     Examples
     --------
     Turbulent example
-    
+
     >>> Nu_external_horizontal_plate(Re=1E7, Pr=.7)
     11496.952599969829
     '''
     turbulent = False if Re < Re_transition else True
-
     if Method is None:
-        methods = []
-        if turbulent:
-            methods.extend(['Schlichting', 'Kreith'])
-        else:
-            methods.extend(['Baehr', 'Churchill Ozoe'])
-        
-    if AvailableMethods:
-        return methods
-    if Method is None:
-        Method = turbulent_method if turbulent else laminar_method
-
-
-    if Method in conv_horizontal_plate_methods:
-        f, args = conv_horizontal_plate_methods[Method]
-        
-        kwargs = {}
-        for arg in args:
-            kwargs[arg] = locals()[arg]
-        return f(**kwargs)
+        Method2 = turbulent_method if turbulent else laminar_method
     else:
-        raise Exception("Correlation name not recognized; see the "
+        Method2 = Method
+
+    if Method2 == 'Baehr':
+        return Nu_horizontal_plate_laminar_Baehr(Re=Re, Pr=Pr)
+    elif Method2 == 'Churchill Ozoe':
+        return Nu_horizontal_plate_laminar_Churchill_Ozoe(Re=Re, Pr=Pr)
+    elif Method2 == 'Schlichting':
+        return Nu_horizontal_plate_turbulent_Schlichting(Re=Re, Pr=Pr)
+    elif Method2 == 'Kreith':
+        return Nu_horizontal_plate_turbulent_Kreith(Re=Re, Pr=Pr)
+    else:
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
