@@ -23,13 +23,15 @@ SOFTWARE.'''
 from __future__ import division
 from math import exp, log
 
-__all__ = ['Nu_vertical_plate_Churchill', 
+__all__ = ['Nu_vertical_plate_Churchill',
            'Nu_free_vertical_plate',
+           'Nu_free_vertical_plate_methods',
            'Nu_horizontal_plate_McAdams',
-           'Nu_horizontal_plate_VDI', 
+           'Nu_horizontal_plate_VDI',
            'Nu_horizontal_plate_Rohsenow',
            'Nu_free_horizontal_plate',
-           'Nu_sphere_Churchill', 
+           'Nu_free_horizontal_plate_methods',
+           'Nu_sphere_Churchill',
            'Nu_vertical_cylinder_Griffiths_Davis_Morgan',
            'Nu_vertical_cylinder_Jakob_Linke_Morgan',
            'Nu_vertical_cylinder_Carne_Morgan',
@@ -41,10 +43,12 @@ __all__ = ['Nu_vertical_plate_Churchill',
            'Nu_vertical_cylinder_Al_Arabi_Khamis',
            'Nu_vertical_cylinder_Popiel_Churchill',
            'Nu_vertical_cylinder',
+           'Nu_vertical_cylinder_methods',
            'Nu_horizontal_cylinder_Churchill_Chu',
            'Nu_horizontal_cylinder_Kuehn_Goldstein',
            'Nu_horizontal_cylinder_Morgan',
            'Nu_horizontal_cylinder',
+           'Nu_horizontal_cylinder_methods',
            'Nu_coil_Xin_Ebadian']
 
 
@@ -102,22 +106,18 @@ def Nu_vertical_plate_Churchill(Pr, Gr):
     term = (0.825 + (0.387*Ra**(1/6.)*(1.0 + (Pr/0.492)**(-0.5625))**(-8.0/27.0)))
     return term*term
 
-Nu_free_vertical_plate_methods = ["Churchill"]
+Nu_free_vertical_plate_all_methods = ["Churchill"]
 
-def Nu_free_vertical_plate(Pr, Gr, H=None, W=None, 
-                           Method=None, AvailableMethods=False):
-    r'''This function calculates the heat transfer coefficient for external
-    free convection from a vertival plate. 
-    
-    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof 
-    number `Gr` for the system fluid, temperatures, and geometry.
-    
-    `L` and `W` are not used by any correlations presently, but are included 
+def Nu_free_vertical_plate_methods(Pr, Gr, H=None, W=None, check_ranges=True):
+    r'''This function returns a list of methods for calculating heat transfer
+    coefficient for external free convection from a verical plate.
+
+    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof
+    number `Gr` for the system fluid (which require T and P to obtain).
+
+    `L` and `W` are not used by any correlations presently, but are included
     for future support.
-    
-    If no correlation's name is provided as `Method`, the 'Churchill' 
-    correlation is selected.
-    
+
     Parameters
     ----------
     Pr : float
@@ -126,7 +126,51 @@ def Nu_free_vertical_plate(Pr, Gr, H=None, W=None,
         Grashof number with respect to fluid properties and plate - fluid
         temperature difference [-]
     H : float, optional
-        height of vertical plate, [m]
+        Height of vertical plate, [m]
+    W : float, optional
+        Width of the vertical plate, [m]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs, [-]
+
+    Examples
+    --------
+    >>> Nu_free_vertical_plate_methods(0.69, 2.63E9)
+    ['Churchill']
+    '''
+    return Nu_free_vertical_plate_all_methods
+
+def Nu_free_vertical_plate(Pr, Gr, buoyancy=None, H=None, W=None, Method=None):
+    r'''This function calculates the heat transfer coefficient for external
+    free convection from a verical plate.
+
+    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof
+    number `Gr` for the system fluid (which require T and P to obtain).
+
+    `L` and `W` are not used by any correlations presently, but are included
+    for future support.
+
+    If no correlation's name is provided as `Method`, the 'Churchill'
+    correlation is selected.
+
+    Parameters
+    ----------
+    Pr : float
+        Prandtl number with respect to fluid properties [-]
+    Gr : float
+        Grashof number with respect to fluid properties and plate - fluid
+        temperature difference [-]
+    buoyancy : bool, optional
+        Whether or not the plate's free convection is buoyancy assisted (hot
+        plate) or not, [-]
+    H : float, optional
+        Height of vertical plate, [m]
     W : float, optional
         Width of the vertical plate, [m]
 
@@ -134,36 +178,28 @@ def Nu_free_vertical_plate(Pr, Gr, H=None, W=None,
     -------
     Nu : float
         Nusselt number with respect to plate height, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Nu` with the given 
-        inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use;
         one of ('Churchill', ).
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `Nu` with the given inputs
-        
+
     Examples
     --------
     Turbulent example
-    
-    >>> Nu_free_vertical_plate(0.69, 2.63E9)
+
+    >>> Nu_free_vertical_plate(0.69, 2.63E9, False)
     147.16185223770603
-    '''        
-    if AvailableMethods:
-        return Nu_free_vertical_plate_methods
+    '''
     if Method is None:
-        Method = Nu_free_vertical_plate_methods[0]
-
-
-    if Method == 'Churchill':
+        Method2 = 'Churchill'
+    else:
+        Method2 = Method
+    if Method2 == 'Churchill':
         return Nu_vertical_plate_Churchill(Pr, Gr)
     else:
-        raise Exception("Correlation name not recognized; see the "
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
 
 
@@ -184,7 +220,7 @@ def Nu_horizontal_plate_McAdams(Pr, Gr, buoyancy=True):
         Grashof number with respect to fluid properties and plate - fluid
         temperature difference [-]
     buoyancy : bool, optional
-        Whether or not the plate's free convection is buoyancy assisted (hot 
+        Whether or not the plate's free convection is buoyancy assisted (hot
         plate) or not, [-]
 
     Returns
@@ -201,12 +237,12 @@ def Nu_horizontal_plate_McAdams(Pr, Gr, buoyancy=True):
     181.73121274384457
     >>> Nu_horizontal_plate_McAdams(5.54, 3.21e8, buoyancy=False)
     55.44564799362829
-    
+
     >>> Nu_horizontal_plate_McAdams(.01, 3.21e8, buoyancy=True)
     22.857041558492334
     >>> Nu_horizontal_plate_McAdams(.01, 3.21e8, buoyancy=False)
     11.428520779246167
-    
+
     References
     ----------
     .. [1] McAdams, William Henry. Heat Transmission. 3E. Malabar, Fla:
@@ -246,7 +282,7 @@ def Nu_horizontal_plate_VDI(Pr, Gr, buoyancy=True):
         Grashof number with respect to fluid properties and plate - fluid
         temperature difference [-]
     buoyancy : bool, optional
-        Whether or not the plate's free convection is buoyancy assisted (hot 
+        Whether or not the plate's free convection is buoyancy assisted (hot
         plate) or not, [-]
 
     Returns
@@ -258,11 +294,11 @@ def Nu_horizontal_plate_VDI(Pr, Gr, buoyancy=True):
     -----
     The characteristic length suggested for use is as follows, with `a` and
     `b` being the length and width of the plate.
-        
+
     .. math::
         L = \frac{ab}{2(a+b)}
-        
-    The buoyancy enhanced cases are from [2]_; the other is said to be from 
+
+    The buoyancy enhanced cases are from [2]_; the other is said to be from
     [3]_, although the equations there not quite the same and do not include
     the Prandtl number correction.
 
@@ -272,13 +308,13 @@ def Nu_horizontal_plate_VDI(Pr, Gr, buoyancy=True):
     203.89681224927565
     >>> Nu_horizontal_plate_VDI(5.54, 3.21e8, buoyancy=False)
     39.16864971535617
-    
+
     References
     ----------
     .. [1] Gesellschaft, V. D. I., ed. VDI Heat Atlas. 2nd ed. 2010 edition.
-       Berlin ; New York: Springer, 2010.   
+       Berlin ; New York: Springer, 2010.
     .. [2] Stewartson, Keith. "On the Free Convection from a Horizontal Plate."
-       Zeitschrift Für Angewandte Mathematik Und Physik ZAMP 9, no. 3 
+       Zeitschrift Für Angewandte Mathematik Und Physik ZAMP 9, no. 3
        (September 1, 1958): 276-82. https://doi.org/10.1007/BF02033031.
     .. [3] Schlunder, Ernst U, and International Center for Heat and Mass
        Transfer. Heat Exchanger Design Handbook. Washington:
@@ -298,11 +334,11 @@ def Nu_horizontal_plate_VDI(Pr, Gr, buoyancy=True):
 
 def Nu_horizontal_plate_Rohsenow(Pr, Gr, buoyancy=True):
     r'''Calculates the Nusselt number for natural convection above a horizontal
-    plate according to the Rohsenow, Hartnett, and Cho (1998) [1]_ correlations. 
-    The plate must be isothermal. Three different equations are used, one each 
-    for laminar and turbulent for the heat transfer happening at upper surface 
+    plate according to the Rohsenow, Hartnett, and Cho (1998) [1]_ correlations.
+    The plate must be isothermal. Three different equations are used, one each
+    for laminar and turbulent for the heat transfer happening at upper surface
     case and one for the case of heat transfer happening at the lower surface.
-    
+
     The lower surface correlation is recommened for the laminar flow regime.
     The two different sets of correlations are required because if the plate
     is hot, buoyancy lifts the fluid off the plate and enhances free convection
@@ -317,7 +353,7 @@ def Nu_horizontal_plate_Rohsenow(Pr, Gr, buoyancy=True):
         Grashof number with respect to fluid properties and plate - fluid
         temperature difference [-]
     buoyancy : bool, optional
-        Whether or not the plate's free convection is buoyancy assisted (hot 
+        Whether or not the plate's free convection is buoyancy assisted (hot
         plate) or not, [-]
 
     Returns
@@ -329,10 +365,10 @@ def Nu_horizontal_plate_Rohsenow(Pr, Gr, buoyancy=True):
     -----
     The characteristic length suggested for use is as follows, with `a` and
     `b` being the length and width of the plate.
-        
+
     .. math::
         L = \frac{ab}{2(a+b)}
-        
+
 
     Examples
     --------
@@ -340,7 +376,7 @@ def Nu_horizontal_plate_Rohsenow(Pr, Gr, buoyancy=True):
     175.91054716322836
     >>> Nu_horizontal_plate_Rohsenow(5.54, 3.21e8, buoyancy=False)
     35.95799244863986
-    
+
     References
     ----------
     .. [1] Rohsenow, Warren and James Hartnett and Young Cho. Handbook of Heat
@@ -350,48 +386,47 @@ def Nu_horizontal_plate_Rohsenow(Pr, Gr, buoyancy=True):
     if buoyancy:
         C_tU = 0.14*((1.0 + 0.01707*Pr)/(1.0 + 0.01*Pr))
         C_tV = 0.13*Pr**0.22/(1.0 + 0.61*Pr**0.81)**0.42
-        
+
         t1 = 1.0 # Ah/A # Heated to non heated area ratio
         t2 = 0.0 # Lf*P/A # Lf vertical distance between lowest and highest point in body
         # P is perimiter, A is area
-        Cl = (0.0972 - (0.0157 + 0.462*C_tV)*t1 
+        Cl = (0.0972 - (0.0157 + 0.462*C_tV)*t1
               + (0.615*C_tV - 0.0548 - 6e-6*Pr)*t2)
-        
+
         Nu_T = 0.835*Cl*Ra**0.25 # average Cl
         Nu_l = 1.4/(log(1.0 + 1.4/Nu_T))
         Nu_t = C_tU*Ra**(1.0/3.0)
-        
+
         m = 10.0
         Nu = ((Nu_l)**m + Nu_t**m)**(1.0/m)
         return Nu
     else:
         # No friction/C term
-        Nu_T = 0.527*Ra**0.2/(1.0 + (1.9/Pr)**0.9)**(2.0/9.0) 
+        Nu_T = 0.527*Ra**0.2/(1.0 + (1.9/Pr)**0.9)**(2.0/9.0)
         Nu_l = 2.5/(log(1.0 + 2.5/Nu_T))
         return Nu_l
 
 
-conv_free_horizontal_plate_methods = {
+conv_free_horizontal_plate_all_methods = {
     'McAdams': (Nu_horizontal_plate_McAdams, ('Pr', 'Gr', 'buoyancy')),
     'VDI': (Nu_horizontal_plate_VDI, ('Pr', 'Gr', 'buoyancy')),
     'Rohsenow': (Nu_horizontal_plate_Rohsenow, ('Pr', 'Gr', 'buoyancy')),
 }
 
+Nu_free_horizontal_plate_all_methods = ["VDI", "McAdams", "Rohsenow"]
 
-def Nu_free_horizontal_plate(Pr, Gr, buoyancy, L=None, W=None, 
-                             Method=None, AvailableMethods=False):
-    r'''This function calculates the heat transfer coefficient for external
-    free convection from a horizontal plate. 
-    
-    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof 
+
+def Nu_free_horizontal_plate_methods(Pr, Gr, buoyancy, L=None, W=None,
+                                     check_ranges=True):
+    r'''This function returns a list of methods for calculating heat transfer
+    coefficient for external free convection from a verical plate.
+
+    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof
     number `Gr` for the system fluid, temperatures, and geometry.
-    
-    `L` and `W` are not used by any correlations presently, but are included 
+
+    `L` and `W` are not used by any correlations presently, but are included
     for future support.
-    
-    If no correlation's name is provided as `Method`, the 'VDI' correlation is
-    selected.
-    
+
     Parameters
     ----------
     Pr : float
@@ -400,7 +435,52 @@ def Nu_free_horizontal_plate(Pr, Gr, buoyancy, L=None, W=None,
         Grashof number with respect to fluid properties and plate - fluid
         temperature difference [-]
     buoyancy : bool, optional
-        Whether or not the plate's free convection is buoyancy assisted (hot 
+        Whether or not the plate's free convection is buoyancy assisted (hot
+        plate) or not, [-]
+    L : float, optional
+        Length of horizontal plate, [m]
+    W : float, optional
+        Width of the horizontal plate, [m]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs, [-]
+
+    Examples
+    --------
+    >>> Nu_free_horizontal_plate_methods(0.69, 2.63E9, True)
+    ['VDI', 'McAdams', 'Rohsenow']
+    '''
+    return Nu_free_horizontal_plate_all_methods
+
+def Nu_free_horizontal_plate(Pr, Gr, buoyancy, L=None, W=None,
+                             Method=None):
+    r'''This function calculates the heat transfer coefficient for external
+    free convection from a horizontal plate.
+
+    Requires at a minimum a fluid's Prandtl number `Pr`, and the Grashof
+    number `Gr` for the system fluid, temperatures, and geometry.
+
+    `L` and `W` are not used by any correlations presently, but are included
+    for future support.
+
+    If no correlation's name is provided as `Method`, the 'VDI' correlation is
+    selected.
+
+    Parameters
+    ----------
+    Pr : float
+        Prandtl number with respect to fluid properties [-]
+    Gr : float
+        Grashof number with respect to fluid properties and plate - fluid
+        temperature difference [-]
+    buoyancy : bool, optional
+        Whether or not the plate's free convection is buoyancy assisted (hot
         plate) or not, [-]
     L : float, optional
         Length of horizontal plate, [m]
@@ -411,47 +491,36 @@ def Nu_free_horizontal_plate(Pr, Gr, buoyancy, L=None, W=None,
     -------
     Nu : float
         Nusselt number with respect to plate length, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Nu` with the given 
-        inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         conv_free_horizontal_plate_methods
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate `Nu` with the given inputs
-        
+
     Examples
     --------
     Turbulent example
-    
+
     >>> Nu_free_horizontal_plate(5.54, 3.21e8, buoyancy=True)
     203.89681224927565
-    
+
     >>> Nu_free_horizontal_plate(5.54, 3.21e8, buoyancy=True, Method='McAdams')
     181.73121274384457
     '''
     if Method is None:
-        methods = ["VDI", "McAdams", "Rohsenow"]
-        
-    if AvailableMethods:
-        return methods
-    if Method is None:
-        Method = methods[0]
-
-
-    if Method in conv_free_horizontal_plate_methods:
-        f, args = conv_free_horizontal_plate_methods[Method]
-        
-        kwargs = {}
-        for arg in args:
-            kwargs[arg] = locals()[arg]
-        return f(**kwargs)
+        Method2 = "VDI"
     else:
-        raise Exception("Correlation name not recognized; see the "
+        Method2 = Method
+
+    if Method2 == 'VDI':
+        return Nu_horizontal_plate_VDI(Pr=Pr, Gr=Gr, buoyancy=buoyancy)
+    if Method2 == 'McAdams':
+        return Nu_horizontal_plate_McAdams(Pr=Pr, Gr=Gr, buoyancy=buoyancy)
+    if Method2 == 'Rohsenow':
+        return Nu_horizontal_plate_Rohsenow(Pr=Pr, Gr=Gr, buoyancy=buoyancy)
+    else:
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
 
 
@@ -522,7 +591,7 @@ def Nu_vertical_cylinder_Griffiths_Davis_Morgan(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -582,7 +651,7 @@ def Nu_vertical_cylinder_Jakob_Linke_Morgan(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -633,6 +702,7 @@ def Nu_vertical_cylinder_Carne_Morgan(Pr, Gr, turbulent=None):
     .. math::
         Nu_H = 1.07 Ra_H^{0.28},\; 2\times 10^{6} < Ra < 2\times 10^{8}
 
+    .. math::
         Nu_H = 0.152 Ra_H^{0.38},\; 2\times 10^{8} < Ra < 2\times 10^{11}
 
     Parameters
@@ -643,7 +713,7 @@ def Nu_vertical_cylinder_Carne_Morgan(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -709,7 +779,7 @@ def Nu_vertical_cylinder_Eigenson_Morgan(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -775,7 +845,7 @@ def Nu_vertical_cylinder_Touloukian_Morgan(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -837,7 +907,7 @@ def Nu_vertical_cylinder_McAdams_Weiss_Saunders(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
     Returns
     -------
@@ -901,7 +971,7 @@ def Nu_vertical_cylinder_Kreith_Eckert(Pr, Gr, turbulent=None):
         Grashof number [-]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
+        result; will return the laminar regime if False; leave as None for
         automatic selection
 
     Returns
@@ -1017,8 +1087,8 @@ def Nu_vertical_cylinder_Al_Arabi_Khamis(Pr, Gr, L, D, turbulent=None):
         Diameter of cylinder, [m]
     turbulent : bool or None, optional
         Whether or not to force the correlation to return the turbulent
-		 result; will return the laminar regime if False; leave as None for
-        automatic selection
+        result; will return the laminar regime if False; leave as None for
+        automatic selection, [-]
 
     Returns
     -------
@@ -1060,8 +1130,7 @@ def Nu_vertical_cylinder_Al_Arabi_Khamis(Pr, Gr, L, D, turbulent=None):
         return 2.9*Ra**0.25*Gr_D**(-1/12.)
 
 
-def Nu_vertical_cylinder_Popiel_Churchill(Pr, Gr, L, D,
-                     Nu_vertical_plate_correlation=Nu_vertical_plate_Churchill):
+def Nu_vertical_cylinder_Popiel_Churchill(Pr, Gr, L, D):
     r'''Calculates Nusselt number for natural convection around a vertical
     isothermal cylinder according to [1]_, also  presented in [2]_.
 
@@ -1084,8 +1153,6 @@ def Nu_vertical_cylinder_Popiel_Churchill(Pr, Gr, L, D,
         Length of vertical cylinder, [m]
     D : float
         Diameter of cylinder, [m]
-    Nu_vertical_plate_correlation : function, optional
-        Correlation for vertical plate heat transfer
 
     Returns
     -------
@@ -1118,7 +1185,7 @@ def Nu_vertical_cylinder_Popiel_Churchill(Pr, Gr, L, D,
     '''
     B = 0.0571322 + 0.20305*Pr**-0.43
     C = 0.9165 - 0.0043*Pr**0.5 + 0.01333*log(Pr) + 0.0004809/Pr
-    Nu_fp = Nu_vertical_plate_correlation(Pr, Gr)
+    Nu_fp = Nu_vertical_plate_Churchill(Pr, Gr)
     return Nu_fp*(1 + B*(32**0.5*Gr**-0.25*L/D)**C)
 
 
@@ -1138,9 +1205,51 @@ vertical_cylinder_correlations = {
 'Popiel & Churchill': (Nu_vertical_cylinder_Popiel_Churchill, False, True, 1.00E+009, False),
 }
 
+def Nu_vertical_cylinder_methods(Pr, Gr, L=None, D=None, check_ranges=True):
+    r'''This function returns a list of correlation names for free convetion
+    to a vertical cylinder.
 
-def Nu_vertical_cylinder(Pr, Gr, L=None, D=None, Method=None,
-                         AvailableMethods=False):
+    The functions returned are 'Popiel & Churchill' for fully defined geometries,
+    and 'McAdams, Weiss & Saunders' otherwise.
+
+    Parameters
+    ----------
+    Pr : float
+        Prandtl number [-]
+    Gr : float
+        Grashof number with respect to cylinder height [-]
+    L : float, optional
+        Length of vertical cylinder, [m]
+    D : float, optional
+        Diameter of cylinder, [m]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs
+
+    Examples
+    --------
+    >>> Nu_vertical_cylinder_methods(0.72, 1E7)[0]
+    'McAdams, Weiss & Saunders'
+    '''
+    if L is None or D is None:
+        return ['McAdams, Weiss & Saunders', 'Churchill Vertical Plate',
+                'Griffiths, Davis, & Morgan', 'Jakob, Linke, & Morgan', 'Carne & Morgan',
+                'Eigenson & Morgan', 'Touloukian & Morgan', 'Kreith & Eckert', 'Hanesian, Kalish & Morgan']
+    else:
+        return ['Popiel & Churchill', 'Churchill Vertical Plate', 'Griffiths, Davis, & Morgan',
+                'Jakob, Linke, & Morgan', 'Carne & Morgan', 'Eigenson & Morgan', 'Touloukian & Morgan',
+                'McAdams, Weiss & Saunders', 'Kreith & Eckert', 'Hanesian, Kalish & Morgan',
+                'Al-Arabi & Khamis']
+
+
+def Nu_vertical_cylinder(Pr, Gr, L=None, D=None, Method=None):
     r'''This function handles choosing which vertical cylinder free convection
     correlation is used. Generally this is used by a helper class, but can be
     used directly. Will automatically select the correlation to use if none is
@@ -1153,7 +1262,7 @@ def Nu_vertical_cylinder(Pr, Gr, L=None, D=None, Method=None,
     --------
     >>> Nu_vertical_cylinder(0.72, 1E7)
     30.562236756513943
-    
+
     Parameters
     ----------
     Pr : float
@@ -1169,50 +1278,53 @@ def Nu_vertical_cylinder(Pr, Gr, L=None, D=None, Method=None,
     -------
     Nu : float
         Nusselt number, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate Nu with the given inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         vertical_cylinder_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate Nu with the given inputs
     '''
-    def list_methods():
-        methods = []
-        for key, values in vertical_cylinder_correlations.items():
-            if values[4] or all((L, D)):
-                methods.append(key)
-        if 'Popiel & Churchill' in methods:
-            methods.remove('Popiel & Churchill')
-            methods.insert(0, 'Popiel & Churchill')
-        elif 'McAdams, Weiss & Saunders' in methods:
-            methods.remove('McAdams, Weiss & Saunders')
-            methods.insert(0, 'McAdams, Weiss & Saunders')
-        return methods
-
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-
-    if Method in vertical_cylinder_correlations:
-        if vertical_cylinder_correlations[Method][4]:
-            return vertical_cylinder_correlations[Method][0](Pr=Pr, Gr=Gr)
+    if Method is None:
+        if L is None or D is None:
+            Method2 = 'McAdams, Weiss & Saunders'
         else:
-            return vertical_cylinder_correlations[Method][0](Pr=Pr, Gr=Gr, L=L, D=D)
+            Method2 = 'Popiel & Churchill'
     else:
-        raise Exception("Correlation name not recognized; see the "
+        Method2 = Method
+
+    if Method2 == 'Churchill Vertical Plate':
+        return Nu_vertical_plate_Churchill(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Griffiths, Davis, & Morgan':
+        return Nu_vertical_cylinder_Griffiths_Davis_Morgan(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Jakob, Linke, & Morgan':
+        return Nu_vertical_cylinder_Jakob_Linke_Morgan(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Carne & Morgan':
+        return Nu_vertical_cylinder_Carne_Morgan(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Eigenson & Morgan':
+        return Nu_vertical_cylinder_Eigenson_Morgan(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Touloukian & Morgan':
+        return Nu_vertical_cylinder_Touloukian_Morgan(Pr=Pr, Gr=Gr)
+    elif Method2 == 'McAdams, Weiss & Saunders':
+        return Nu_vertical_cylinder_McAdams_Weiss_Saunders(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Kreith & Eckert':
+        return Nu_vertical_cylinder_Kreith_Eckert(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Hanesian, Kalish & Morgan':
+        return Nu_vertical_cylinder_Hanesian_Kalish_Morgan(Pr=Pr, Gr=Gr)
+
+    elif Method2 == 'Al-Arabi & Khamis':
+        return Nu_vertical_cylinder_Al_Arabi_Khamis(Pr=Pr, Gr=Gr, L=L, D=D)
+    elif Method2 == 'Popiel & Churchill':
+        return Nu_vertical_cylinder_Popiel_Churchill(Pr=Pr, Gr=Gr, L=L, D=D)
+    else:
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
 
 #import matplotlib.pyplot as plt
 #import numpy as np
 ##L, D = 1.5, 0.1
 #Pr, Gr = 0.72, 1E8
-#methods = Nu_vertical_cylinder(Pr, Gr, AvailableMethods=True)
+#methods = Nu_vertical_cylinder_methods(Pr, Gr)
 #Grs = np.logspace(2, 12, 10000)
 #
 #for method in methods:
@@ -1400,7 +1512,37 @@ horizontal_cylinder_correlations = {
 'Morgan': (Nu_horizontal_cylinder_Morgan)
 }
 
-def Nu_horizontal_cylinder(Pr, Gr, Method=None, AvailableMethods=False):
+def Nu_horizontal_cylinder_methods(Pr, Gr, check_ranges=True):
+    r'''This function returns a list of correlation names for free convetion
+    to a horizontal cylinder.
+
+    Preferred functions are 'Morgan' when discontinuous results are acceptable
+    and 'Churchill-Chu' otherwise.
+
+    Parameters
+    ----------
+    Pr : float
+        Prandtl number with respect to film temperature [-]
+    Gr : float
+        Grashof number with respect to cylinder diameter, [-]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list[str]
+        List of methods which can be used to calculate `Nu` with the given
+        inputs
+
+    Examples
+    --------
+    >>> Nu_horizontal_cylinder_methods(0.72, 1E7)[0]
+    'Morgan'
+    '''
+    return ['Morgan', 'Churchill-Chu', 'Kuehn & Goldstein']
+
+def Nu_horizontal_cylinder(Pr, Gr, Method=None):
     r'''This function handles choosing which horizontal cylinder free convection
     correlation is used. Generally this is used by a helper class, but can be
     used directly. Will automatically select the correlation to use if none is
@@ -1420,25 +1562,20 @@ def Nu_horizontal_cylinder(Pr, Gr, Method=None, AvailableMethods=False):
     -------
     Nu : float
         Nusselt number with respect to cylinder diameter, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate Nu with the given inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         horizontal_cylinder_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate Nu with the given inputs
-        
+
     Notes
     -----
-    All fluid properties should be evaluated at the film temperature, the 
+    All fluid properties should be evaluated at the film temperature, the
     average between the outer surface temperature of the solid, and the fluid
     temperature far away from the heat transfer interface - normally the same
     as the temperature before any cooling or heating occurs.
-    
+
     .. math::
         T_f = (T_{\text{surface}} + T_\infty)/2
 
@@ -1447,31 +1584,25 @@ def Nu_horizontal_cylinder(Pr, Gr, Method=None, AvailableMethods=False):
     >>> Nu_horizontal_cylinder(0.72, 1E7)
     24.864192615468973
     '''
-    def list_methods():
-        methods = []
-        for key, values in horizontal_cylinder_correlations.items():
-                methods.append(key)
-        if 'Morgan' in methods:
-            methods.remove('Morgan')
-            methods.insert(0, 'Morgan')
-        return methods
-
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-
-    if Method in horizontal_cylinder_correlations:
-        return horizontal_cylinder_correlations[Method](Pr=Pr, Gr=Gr)
+    if Method is None:
+        Method2 = 'Morgan'
     else:
-        raise Exception("Correlation name not recognized; see the "
+        Method2 = Method
+    if Method2 == 'Churchill-Chu':
+        return Nu_horizontal_cylinder_Churchill_Chu(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Kuehn & Goldstein':
+        return Nu_horizontal_cylinder_Kuehn_Goldstein(Pr=Pr, Gr=Gr)
+    elif Method2 == 'Morgan':
+        return Nu_horizontal_cylinder_Morgan(Pr=Pr, Gr=Gr)
+    else:
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
 
 
 #import matplotlib.pyplot as plt
 #import numpy as np
 #Pr, Gr = 0.72, 1E8
-#methods = Nu_horizontal_cylinder(Pr, Gr, AvailableMethods=True)
+#methods = Nu_horizontal_cylinder_methods(Pr, Gr)
 #Grs = np.logspace(-2, 2.5, 10000)
 #
 #for method in methods:
@@ -1483,16 +1614,16 @@ def Nu_horizontal_cylinder(Pr, Gr, Method=None, AvailableMethods=False):
 
 def Nu_coil_Xin_Ebadian(Pr, Gr, horizontal=False):
     r'''Calculates Nusselt number for natural convection around a vertical
-    or horizontal helical coil suspended in a fluid without 
-    forced convection. 
-    
+    or horizontal helical coil suspended in a fluid without
+    forced convection.
+
     For horizontal cases:
-    
+
     .. math::
         Nu_D = 0.318 Ra_D^{0.293},\; 5 \times {10}^{3} < Ra < 1 \times {10}^5
 
     For vertical cases:
-    
+
     .. math::
         Nu_D = 0.290 Ra_D^{0.293},\; 5 \times {10}^{3} < Ra < 1 \times {10}^5
 
@@ -1524,15 +1655,15 @@ def Nu_coil_Xin_Ebadian(Pr, Gr, horizontal=False):
     4.755689726250451
     >>> Nu_coil_Xin_Ebadian(0.7, 2E4, horizontal=True)
     5.2148597687849785
-    
+
     References
     ----------
-    .. [1] Xin, R. C., and M. A. Ebadian. "Natural Convection Heat Transfer 
-       from Helicoidal Pipes." Journal of Thermophysics and Heat Transfer 10, 
-       no. 2 (1996): 297-302. 
+    .. [1] Xin, R. C., and M. A. Ebadian. "Natural Convection Heat Transfer
+       from Helicoidal Pipes." Journal of Thermophysics and Heat Transfer 10,
+       no. 2 (1996): 297-302.
     .. [2] Prabhanjan, Devanahalli G., Timothy J. Rennie, and G. S. Vijaya
        Raghavan. "Natural Convection Heat Transfer from Helical Coiled Tubes."
-       International Journal of Thermal Sciences 43, no. 4 (April 1, 2004): 
+       International Journal of Thermal Sciences 43, no. 4 (April 1, 2004):
        359-65.
     '''
     Ra = Pr*Gr
