@@ -33,13 +33,15 @@ __all__ = ['laminar_T_const', 'laminar_Q_const',
 'turbulent_Churchill_Zajic', 'turbulent_ESDU', 'turbulent_Martinelli',
 'turbulent_Nunner', 'turbulent_Dipprey_Sabersky', 'turbulent_Gowen_Smith',
 'turbulent_Kawase_Ulbrecht', 'turbulent_Kawase_De', 'turbulent_Bhatti_Shah',
-'Nu_conv_internal', 'Morimoto_Hotta', 'helical_turbulent_Nu_Mori_Nakayama',
-'helical_turbulent_Nu_Schmidt', 'helical_turbulent_Nu_Xin_Ebadian', 
+'Nu_conv_internal', 'Nu_conv_internal_methods',
+
+'Morimoto_Hotta', 'helical_turbulent_Nu_Mori_Nakayama',
+'helical_turbulent_Nu_Schmidt', 'helical_turbulent_Nu_Xin_Ebadian',
 'Nu_laminar_rectangular_Shan_London',
 'conv_tube_methods', 'conv_tube_laminar_methods', 'conv_tube_turbulent_methods']
 
 from math import log, log10, exp, tanh
-from fluids.friction import friction_factor, LAMINAR_TRANSITION_PIPE
+from fluids.friction import friction_factor, Clamond, LAMINAR_TRANSITION_PIPE
 
 ### Laminar
 
@@ -208,7 +210,7 @@ def laminar_entry_Seider_Tate(Re, Pr, L, Di, mu=None, mu_w=None):
        Applications and Rules of Thumb. 2E. Amsterdam: Academic Press, 2014.
     '''
     Nu = 1.86*(Di/L*Re*Pr)**(1/3.0)
-    if mu_w and mu:
+    if mu_w is not None and mu is not None:
         Nu *= (mu/mu_w)**0.14
     return Nu
 
@@ -379,7 +381,7 @@ def turbulent_Sieder_Tate(Re, Pr, mu=None, mu_w=None):
        (December 1, 1936): 1429-35. doi:10.1021/ie50324a027.
     '''
     Nu = 0.027*Re**0.8*Pr**(1/3.)
-    if mu_w and mu:
+    if mu_w is not None and mu is not None:
         Nu *= (mu/mu_w)**0.14
     return Nu
 
@@ -762,7 +764,7 @@ def turbulent_Sandall(Re, Pr, fd):
        (August 1, 1980): 443–47. doi:10.1002/cjce.5450580404.
     '''
     C = 2.78*log((fd/8.)**0.5*Re/45.)
-    return (fd/8.)**0.5*Re*Pr/(12.48*Pr**(2/3.) - 7.853*Pr**(1/3.) 
+    return (fd/8.)**0.5*Re*Pr/(12.48*Pr**(2/3.) - 7.853*Pr**(1/3.)
                                + 3.613*log(Pr) + 5.8 + C)
 
 
@@ -1293,8 +1295,8 @@ def turbulent_Bhatti_Shah(Re, Pr, fd, eD):
 conv_tube_laminar_methods = {
     'Laminar - constant T': (laminar_T_const, ()),
     'Laminar - constant Q': (laminar_Q_const, ()),
-    'Baehr-Stephan laminar thermal/velocity entry': (laminar_entry_thermal_Hausen, ('Re', 'Pr', 'L', 'Di')), 
-     'Hausen laminar thermal entry': (laminar_entry_Seider_Tate, ('Re', 'Pr', 'L', 'Di')), 
+    'Baehr-Stephan laminar thermal/velocity entry': (laminar_entry_thermal_Hausen, ('Re', 'Pr', 'L', 'Di')),
+     'Hausen laminar thermal entry': (laminar_entry_Seider_Tate, ('Re', 'Pr', 'L', 'Di')),
     'Seider-Tate laminar thermal entry': (laminar_entry_Baehr_Stephan, ('Re', 'Pr', 'L', 'Di')),
 }
 
@@ -1311,7 +1313,7 @@ conv_tube_turbulent_methods = {
     'Gowen-Smith': (turbulent_Gowen_Smith, ('Re', 'Pr', 'fd')),
     'Kawase-Ulbrecht': (turbulent_Kawase_Ulbrecht, ('Re', 'Pr', 'fd')),
     'Kawase-De': (turbulent_Kawase_De, ('Re', 'Pr', 'fd')),
-    
+
     'Dittus-Boelter': (turbulent_Dittus_Boelter, ('Re', 'Pr')),
     'Sieder-Tate': (turbulent_Sieder_Tate, ('Re', 'Pr')),
     'Drexel-McAdams': (turbulent_Drexel_McAdams, ('Re', 'Pr')),
@@ -1319,7 +1321,7 @@ conv_tube_turbulent_methods = {
     'ESDU': (turbulent_ESDU, ('Re', 'Pr')),
     'Gnielinski smooth low Pr': (turbulent_Gnielinski_smooth_1, ('Re', 'Pr')),
     'Gnielinski smooth high Pr': (turbulent_Gnielinski_smooth_2, ('Re', 'Pr')),
-    
+
     'Hausen': (turbulent_entry_Hausen, ('Re', 'Pr', 'Di', 'x')),
     'Bhatti-Shah': (turbulent_Bhatti_Shah, ('Re', 'Pr', 'fd', 'eD')),
     'Dipprey-Sabersky': (turbulent_Dipprey_Sabersky, ('Re', 'Pr', 'fd', 'eD')),
@@ -1328,23 +1330,104 @@ conv_tube_turbulent_methods = {
 
 conv_tube_methods = conv_tube_laminar_methods.copy()
 conv_tube_methods.update(conv_tube_turbulent_methods)
+conv_tube_methods_list = list(conv_tube_methods.keys())
 
+def Nu_conv_internal_methods(Re, Pr, eD=0, Di=None, x=None, fd=None,
+                             check_ranges=True):
+    r'''This function returns a list of correlation names for the calculation
+    of heat transfer coefficient for internal convection inside a circular pipe.
 
-def Nu_conv_internal(Re, Pr, eD=0, Di=None, x=None, fd=None, Method=None, 
-                     AvailableMethods=False):
+    Parameters
+    ----------
+    Re : float
+        Reynolds number, [-]
+    Pr : float
+        Prandtl number, [-]
+    eD : float, optional
+        Relative roughness, [-]
+    Di : float, optional
+        Inside diameter of pipe, [m]
+    x : float, optional
+        Length inside of pipe for calculation, [m]
+    fd : float, optoinal
+        Darcy friction factor [-]
+    check_ranges : bool, optional
+        Whether or not to return only correlations suitable for the provided
+        data, [-]
+
+    Returns
+    -------
+    methods : list
+        List of methods which can be used to calculate `Nu` with the given inputs
+
+    Examples
+    --------
+    Turbulent example
+
+    >>> Nu_conv_internal_methods(Re=1E5, Pr=.7)[0]
+    'Churchill-Zajic'
+
+    Entry length - laminar example
+
+    >>> Nu_conv_internal_methods(Re=1E2, Pr=.7, x=.01, Di=.1)[0]
+    'Baehr-Stephan laminar thermal/velocity entry'
+    '''
+    methods = []
+    if Re < LAMINAR_TRANSITION_PIPE or not check_ranges:
+        # Laminar!
+        if (Re is not None and Pr is not None and x is not None and Di is not None):
+            methods.append('Baehr-Stephan laminar thermal/velocity entry')
+            methods.append('Hausen laminar thermal entry')
+            methods.append('Seider-Tate laminar thermal entry')
+
+        methods.append('Laminar - constant T')
+        methods.append('Laminar - constant Q')
+    if Re >= LAMINAR_TRANSITION_PIPE or not check_ranges:
+        if (Re is not None and Pr is not None and Pr < 0.03) or not check_ranges:
+            # Liquid metals
+            methods.append('Martinelli')
+        if (Re is not None and Pr is not None and x is not None and Di is not None) or not check_ranges:
+            methods.append('Hausen')
+        if (Re is not None and Pr is not None and (eD is not None or fd is not None)) or not check_ranges:
+            # handle correlations with roughness
+            methods.append('Churchill-Zajic')
+            methods.append('Petukhov-Kirillov-Popov')
+            methods.append('Gnielinski')
+            methods.append('Bhatti-Shah')
+            methods.append('Dipprey-Sabersky')
+            methods.append('Sandall')
+            methods.append('Webb')
+            methods.append('Friend-Metzner')
+            methods.append('Prandtl')
+            methods.append('von-Karman')
+            methods.append('Gowen-Smith')
+            methods.append('Kawase-Ulbrecht')
+            methods.append('Kawase-De')
+            methods.append('Nunner')
+        if (Re is not None and Pr is not None) or not check_ranges:
+            methods.append('Dittus-Boelter')
+            methods.append('Sieder-Tate')
+            methods.append('Drexel-McAdams')
+            methods.append('Colburn')
+            methods.append('ESDU')
+            methods.append('Gnielinski smooth low Pr') # 1
+            methods.append('Gnielinski smooth high Pr') # 2
+    return methods
+
+def Nu_conv_internal(Re, Pr, eD=0.0, Di=None, x=None, fd=None, Method=None):
     r'''This function calculates the heat transfer coefficient for internal
-    convection inside a circular pipe. 
-    
-    Requires at a minimum a flow's Reynolds and Prandtl numbers `Re` and `Pr`. 
-    Relative roughness `eD` can be specified to include the enhancement of heat 
-    transfer from the added turbulence. 
-    
+    convection inside a circular pipe.
+
+    Requires at a minimum a flow's Reynolds and Prandtl numbers `Re` and `Pr`.
+    Relative roughness `eD` can be specified to include the enhancement of heat
+    transfer from the added turbulence.
+
     For laminar flow, thermally and hydraulically developing flow is supported
     with the pipe diameter `Di` and distance `x` is provided.
-    
-    If no correlation's name is provided as `Method`, the most accurate 
+
+    If no correlation's name is provided as `Method`, the most accurate
     applicable correlation is selected.
-    
+
     * If laminar, `x` and `Di` provided:  'Baehr-Stephan laminar thermal/velocity entry'
     * Otherwise if laminar, no entry information provided: 'Laminar - constant T' (Nu = 3.66)
     * If turbulent and `Pr` < 0.03: 'Martinelli'
@@ -1370,93 +1453,93 @@ def Nu_conv_internal(Re, Pr, eD=0, Di=None, x=None, fd=None, Method=None,
     -------
     Nu : float
         Nusselt number, [-]
-    methods : list, only returned if AvailableMethods == True
-        List of methods which can be used to calculate `Nu` with the given inputs
 
     Other Parameters
     ----------------
     Method : string, optional
         A string of the function name to use, as in the dictionary
         vertical_cylinder_correlations
-    AvailableMethods : bool, optional
-        If True, function will consider which methods which can be used to
-        calculate Nu with the given inputs
-        
+
     Examples
     --------
     Turbulent example
-    
+
     >>> Nu_conv_internal(Re=1E5, Pr=.7)
     183.71057902604906
 
     Entry length - laminar example
-    
+
     >>> Nu_conv_internal(Re=1E2, Pr=.7, x=.01, Di=.1)
     14.91799128769779
     '''
-    def list_methods():
-        methods = []
-        if Re < LAMINAR_TRANSITION_PIPE:
-            # Laminar!
-            if all((Re, Pr, x, Di)):
-                methods.append('Baehr-Stephan laminar thermal/velocity entry')
-                methods.append('Hausen laminar thermal entry')
-                methods.append('Seider-Tate laminar thermal entry')
+    if Method is None:
+        Method2 = Nu_conv_internal_methods(Re=Re, Pr=Pr, eD=eD, Di=Di, x=x, fd=fd, check_ranges=True)[0]
+    else:
+        Method2 = Method
 
-            methods.append('Laminar - constant T')
-            methods.append('Laminar - constant Q')
-        else:
-            if all((Re, Pr)) and Pr < 0.03:
-                # Liquid metals
-                methods.append('Martinelli')
-            if all((Re, Pr, Di, x)):
-                methods.append('Hausen')
-            if Re and Pr and (eD is not None or fd is not None):
-                # handle correlations with roughness
-                methods.append('Churchill-Zajic')
-                methods.append('Petukhov-Kirillov-Popov')
-                methods.append('Gnielinski')
-                methods.append('Bhatti-Shah')
-                methods.append('Dipprey-Sabersky')
-                methods.append('Sandall')
-                methods.append('Webb')
-                methods.append('Friend-Metzner')
-                methods.append('Prandtl')
-                methods.append('von-Karman')
-                methods.append('Gowen-Smith')
-                methods.append('Kawase-Ulbrecht')
-                methods.append('Kawase-De')
-                methods.append('Nunner')
-            if Re and Pr:
-                methods.append('Dittus-Boelter')
-                methods.append('Sieder-Tate')
-                methods.append('Drexel-McAdams')
-                methods.append('Colburn')
-                methods.append('ESDU')
-                methods.append('Gnielinski smooth low Pr') # 1
-                methods.append('Gnielinski smooth high Pr') # 2
-        return methods
-
-    if AvailableMethods:
-        return list_methods()
-    if not Method:
-        Method = list_methods()[0]
-        
     L = x
     if eD is not None and fd is None:
-        fd = friction_factor(Re=Re, eD=eD)
+        fd = Clamond(Re=Re, eD=eD)
 
-    if Method in conv_tube_methods:
-        f, args = conv_tube_methods[Method]
-        if f is turbulent_Nunner:
-            fd_smooth = friction_factor(Re, eD=0)
-        
-        kwargs = {}
-        for arg in args:
-            kwargs[arg] = locals()[arg]
-        return f(**kwargs)
+    if Method2 == "Laminar - constant T":
+        return laminar_T_const()
+    elif Method2 == "Laminar - constant Q":
+        return laminar_Q_const()
+    elif Method2 == "Baehr-Stephan laminar thermal/velocity entry":
+        return laminar_entry_thermal_Hausen(Re=Re, Pr=Pr, L=L, Di=Di)
+    elif Method2 == "Hausen laminar thermal entry":
+        return laminar_entry_Seider_Tate(Re=Re, Pr=Pr, L=L, Di=Di)
+    elif Method2 == "Seider-Tate laminar thermal entry":
+        return laminar_entry_Baehr_Stephan(Re=Re, Pr=Pr, L=L, Di=Di)
+    elif Method2 == "Churchill-Zajic":
+        return turbulent_Churchill_Zajic(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Petukhov-Kirillov-Popov":
+        return turbulent_Petukhov_Kirillov_Popov(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Gnielinski":
+        return turbulent_Gnielinski(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Sandall":
+        return turbulent_Sandall(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Webb":
+        return turbulent_Webb(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Friend-Metzner":
+        return turbulent_Friend_Metzner(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Prandtl":
+        return turbulent_Prandtl(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "von-Karman":
+        return turbulent_von_Karman(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Martinelli":
+        return turbulent_Martinelli(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Gowen-Smith":
+        return turbulent_Gowen_Smith(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Kawase-Ulbrecht":
+        return turbulent_Kawase_Ulbrecht(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Kawase-De":
+        return turbulent_Kawase_De(Re=Re, Pr=Pr, fd=fd)
+    elif Method2 == "Dittus-Boelter":
+        return turbulent_Dittus_Boelter(Re=Re, Pr=Pr)
+    elif Method2 == "Sieder-Tate":
+        return turbulent_Sieder_Tate(Re=Re, Pr=Pr)
+    elif Method2 == "Drexel-McAdams":
+        return turbulent_Drexel_McAdams(Re=Re, Pr=Pr)
+    elif Method2 == "Colburn":
+        return turbulent_Colburn(Re=Re, Pr=Pr)
+    elif Method2 == "ESDU":
+        return turbulent_ESDU(Re=Re, Pr=Pr)
+    elif Method2 == "Gnielinski smooth low Pr":
+        return turbulent_Gnielinski_smooth_1(Re=Re, Pr=Pr)
+    elif Method2 == "Gnielinski smooth high Pr":
+        return turbulent_Gnielinski_smooth_2(Re=Re, Pr=Pr)
+    elif Method2 == "Hausen":
+        return turbulent_entry_Hausen(Re=Re, Pr=Pr, Di=Di, x=x)
+    elif Method2 == "Bhatti-Shah":
+        return turbulent_Bhatti_Shah(Re=Re, Pr=Pr, fd=fd, eD=eD)
+    elif Method2 == "Dipprey-Sabersky":
+        return turbulent_Dipprey_Sabersky(Re=Re, Pr=Pr, fd=fd, eD=eD)
+    elif Method2 == "Nunner":
+        fd_smooth = Clamond(Re, eD=0.0)
+        return turbulent_Nunner(Re=Re, Pr=Pr, fd=fd, fd_smooth=fd_smooth)
     else:
-        raise Exception("Correlation name not recognized; see the "
+        raise ValueError("Correlation name not recognized; see the "
                         "documentation for the available options.")
     return Nu
 
@@ -1469,7 +1552,7 @@ def Nu_conv_internal(Re, Pr, eD=0, Di=None, x=None, fd=None, Method=None,
 #Di = 0.0254*4
 #roughness = .00015
 #
-#methods = Nu_conv_internal(Re=10000, Pr=Pr, fd=1.8E-5, x=2.5, Di=0.5, AvailableMethods=True, Method=None)
+#methods = Nu_conv_internal_methods(Re=10000, Pr=Pr, fd=1.8E-5, x=2.5, Di=0.5)
 #
 #plt.figure()
 #Res = np.logspace(4, 6, 300)
@@ -1492,16 +1575,16 @@ def Morimoto_Hotta(Re, Pr, Dh, Rm):
     r'''Calculates Nusselt number for flow inside a spiral heat exchanger of
     spiral mean diameter `Rm` and hydraulic diameter `Dh` according to [1]_,
     also as shown in [2]_ and [3]_.
-    
+
     .. math::
         Nu = 0.0239\left(1 + 5.54\frac{D_h}{R_m}\right)Re^{0.806}Pr^{0.268}
-        
+
     .. math::
         D_h = \frac{2HS}{H+S}
-        
+
     .. math::
         R_m = \frac{R_{min} + R_{max}}{2}
-    
+
 
     Parameters
     ----------
@@ -1530,18 +1613,18 @@ def Morimoto_Hotta(Re, Pr, Dh, Rm):
 
     References
     ----------
-    .. [1] Morimoto, Eiji, and Kazuyuki Hotta. "Study of Geometric Structure 
-       and Heat Transfer Characteristics of Spiral Plate Heat Exchanger." 
-       Transactions of the Japan Society of Mechanical Engineers Series B 52, 
+    .. [1] Morimoto, Eiji, and Kazuyuki Hotta. "Study of Geometric Structure
+       and Heat Transfer Characteristics of Spiral Plate Heat Exchanger."
+       Transactions of the Japan Society of Mechanical Engineers Series B 52,
        no. 474 (1986): 926-33. doi:10.1299/kikaib.52.926.
-    .. [2] Bidabadi, M. and Sadaghiani, A. and Azad, A. "Spiral heat exchanger 
-       optimization using genetic algorithm." Transaction on Mechanical 
+    .. [2] Bidabadi, M. and Sadaghiani, A. and Azad, A. "Spiral heat exchanger
+       optimization using genetic algorithm." Transaction on Mechanical
        Engineering, International Journal of Science and Technology,
-       vol. 20, no. 5 (2013): 1445-1454. 
+       vol. 20, no. 5 (2013): 1445-1454.
        http://www.scientiairanica.com/en/ManuscriptDetail?mid=47.
-    .. [3] Turgut, Oğuz Emrah, and Mustafa Turhan Çoban. "Thermal Design of 
-       Spiral Heat Exchangers and Heat Pipes through Global Best Algorithm." 
-       Heat and Mass Transfer, July 7, 2016, 1-18. 
+    .. [3] Turgut, Oğuz Emrah, and Mustafa Turhan Çoban. "Thermal Design of
+       Spiral Heat Exchangers and Heat Pipes through Global Best Algorithm."
+       Heat and Mass Transfer, July 7, 2016, 1-18.
        doi:10.1007/s00231-016-1861-y.
     '''
     return 0.0239*(1. + 5.54*Dh/Rm)*Re**0.806*Pr**0.268
@@ -1552,24 +1635,24 @@ def Morimoto_Hotta(Re, Pr, Dh, Rm):
 
 
 def helical_turbulent_Nu_Mori_Nakayama(Re, Pr, Di, Dc):
-    r'''Calculates Nusselt number for a fluid flowing inside a curved 
-    pipe such as a helical coil under turbulent conditions, using the method of 
+    r'''Calculates Nusselt number for a fluid flowing inside a curved
+    pipe such as a helical coil under turbulent conditions, using the method of
     Mori and Nakayama [1]_, also shown in [2]_ and [3]_.
-            
+
     For :math:`Pr < 1`:
-        
+
     .. math::
         Nu = \frac{Pr}{26.2(Pr^{2/3}-0.074)}Re^{0.8}\left(\frac{D_i}{D_c}
         \right)^{0.1}\left[1 + \frac{0.098}{\left[Re\left(\frac{D_i}{D_c}
         \right)^2\right]^{0.2}}\right]
-            
+
     For :math:`Pr \ge 1`:
-        
+
     .. math::
         Nu = \frac{Pr^{0.4}}{41}Re^{5/6}\left(\frac{D_i}{D_c}\right)^{1/12}
         \left[1 + \frac{0.061}{\left[Re\left(\frac{D_i}{D_c}\right)^{2.5}
         \right]^{1/6}}\right]
-        
+
     Parameters
     ----------
     Re : float
@@ -1588,10 +1671,10 @@ def helical_turbulent_Nu_Mori_Nakayama(Re, Pr, Di, Dc):
         Nusselt number with respect to `Di`, [-]
 
     Notes
-    -----    
+    -----
     At very low curvatures, the predicted heat transfer coefficient
     grows unbounded.
-    
+
     Applicable for :math:`Re\left(\frac{D_i}{D_c}\right)^2 > 0.1`
 
     Examples
@@ -1601,17 +1684,17 @@ def helical_turbulent_Nu_Mori_Nakayama(Re, Pr, Di, Dc):
 
     References
     ----------
-    .. [1] Mori, Yasuo, and Wataru Nakayama. "Study on Forced Convective Heat 
-       Transfer in Curved Pipes." International Journal of Heat and Mass 
-       Transfer 10, no. 5 (May 1, 1967): 681-95. 
-       doi:10.1016/0017-9310(67)90113-5. 
-    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and 
-       Correlations for Convection Heat Transfer and Pressure Losses in 
+    .. [1] Mori, Yasuo, and Wataru Nakayama. "Study on Forced Convective Heat
+       Transfer in Curved Pipes." International Journal of Heat and Mass
+       Transfer 10, no. 5 (May 1, 1967): 681-95.
+       doi:10.1016/0017-9310(67)90113-5.
+    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and
+       Correlations for Convection Heat Transfer and Pressure Losses in
        Toroidal and Helically Coiled Tubes." Heat Transfer Engineering 0, no. 0
        (June 7, 2016): 1-28. doi:10.1080/01457632.2016.1194693.
-    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat 
-       Transfer Coefficient in Helical Coils with Single Phase Flow." 
-       International Journal of Heat and Mass Transfer 89 (October 2015): 
+    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat
+       Transfer Coefficient in Helical Coils with Single Phase Flow."
+       International Journal of Heat and Mass Transfer 89 (October 2015):
        522-38. doi:10.1016/j.ijheatmasstransfer.2015.05.069.
     '''
     D_ratio = Di/Dc
@@ -1625,23 +1708,23 @@ def helical_turbulent_Nu_Mori_Nakayama(Re, Pr, Di, Dc):
 
 
 def helical_turbulent_Nu_Schmidt(Re, Pr, Di, Dc):
-    r'''Calculates Nusselt number for a fluid flowing inside a curved 
-    pipe such as a helical coil under turbulent conditions, using the method of 
+    r'''Calculates Nusselt number for a fluid flowing inside a curved
+    pipe such as a helical coil under turbulent conditions, using the method of
     Schmidt [1]_, also shown in [2]_, [3]_, and [4]_.
-            
+
     For :math:`Re_{crit} < Re < 2.2\times 10 ^4`:
-        
+
     .. math::
         Nu = 0.023\left[1 + 14.8\left(1 + \frac{D_i}{D_c}\right)\left(
         \frac{D_i}{D_c}\right)^{1/3}\right]Re^{0.8-0.22\left(\frac{D_i}{D_c}
         \right)^{0.1}}Pr^{1/3}
-            
+
     For :math:`2.2\times 10^4 < Re < 1.5\times 10^5`:
-        
+
     .. math::
         Nu = 0.023\left[1 + 3.6\left(1 - \frac{D_i}{D_c}\right)\left(\frac{D_i}
         {D_c}\right)^{0.8}\right]Re^{0.8}Pr^{1/3}
-        
+
     Parameters
     ----------
     Re : float
@@ -1658,7 +1741,7 @@ def helical_turbulent_Nu_Schmidt(Re, Pr, Di, Dc):
     -------
     Nu : float
         Nusselt number with respect to `Di`, [-]
-        
+
     Notes
     -----
     For very low curvatures, reasonable results are returned by both cases
@@ -1671,16 +1754,16 @@ def helical_turbulent_Nu_Schmidt(Re, Pr, Di, Dc):
 
     References
     ----------
-    .. [1] Schmidt, Eckehard F. "Wärmeübergang Und Druckverlust in 
-       Rohrschlangen." Chemie Ingenieur Technik 39, no. 13 (July 10, 1967): 
-       781-89. doi:10.1002/cite.330391302. 
-    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and 
-       Correlations for Convection Heat Transfer and Pressure Losses in 
+    .. [1] Schmidt, Eckehard F. "Wärmeübergang Und Druckverlust in
+       Rohrschlangen." Chemie Ingenieur Technik 39, no. 13 (July 10, 1967):
+       781-89. doi:10.1002/cite.330391302.
+    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and
+       Correlations for Convection Heat Transfer and Pressure Losses in
        Toroidal and Helically Coiled Tubes." Heat Transfer Engineering 0, no. 0
        (June 7, 2016): 1-28. doi:10.1080/01457632.2016.1194693.
-    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat 
-       Transfer Coefficient in Helical Coils with Single Phase Flow." 
-       International Journal of Heat and Mass Transfer 89 (October 2015): 
+    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat
+       Transfer Coefficient in Helical Coils with Single Phase Flow."
+       International Journal of Heat and Mass Transfer 89 (October 2015):
        522-38. doi:10.1016/j.ijheatmasstransfer.2015.05.069.
     .. [4] Rohsenow, Warren and James Hartnett and Young Cho. Handbook of Heat
        Transfer, 3E. New York: McGraw-Hill, 1998.
@@ -1694,16 +1777,16 @@ def helical_turbulent_Nu_Schmidt(Re, Pr, Di, Dc):
 
 
 def helical_turbulent_Nu_Xin_Ebadian(Re, Pr, Di, Dc):
-    r'''Calculates Nusselt number for a fluid flowing inside a curved 
-    pipe such as a helical coil under turbulent conditions, using the method of 
+    r'''Calculates Nusselt number for a fluid flowing inside a curved
+    pipe such as a helical coil under turbulent conditions, using the method of
     Xin and Ebadian [1]_, also shown in [2]_ and [3]_.
-            
+
     For :math:`Re_{crit} < Re < 1\times 10^5`:
-        
+
     .. math::
         Nu = 0.00619Re^{0.92} Pr^{0.4}\left[1 + 3.455\left(\frac{D_i}{D_c}
         \right)\right]
-        
+
     Parameters
     ----------
     Re : float
@@ -1720,12 +1803,12 @@ def helical_turbulent_Nu_Xin_Ebadian(Re, Pr, Di, Dc):
     -------
     Nu : float
         Nusselt number with respect to `Di`, [-]
-        
+
     Notes
     -----
     For very low curvatures, reasonable results are returned.
-    
-    The correlation was developed with data in the range of 
+
+    The correlation was developed with data in the range of
     :math:`0.7 < Pr < 5; 0.0267 < \frac{D_i}{D_c} < 0.0884`.
 
     Examples
@@ -1735,17 +1818,17 @@ def helical_turbulent_Nu_Xin_Ebadian(Re, Pr, Di, Dc):
 
     References
     ----------
-    .. [1] Xin, R. C., and M. A. Ebadian. "The Effects of Prandtl Numbers on 
-       Local and Average Convective Heat Transfer Characteristics in Helical 
-       Pipes." Journal of Heat Transfer 119, no. 3 (August 1, 1997): 467-73. 
+    .. [1] Xin, R. C., and M. A. Ebadian. "The Effects of Prandtl Numbers on
+       Local and Average Convective Heat Transfer Characteristics in Helical
+       Pipes." Journal of Heat Transfer 119, no. 3 (August 1, 1997): 467-73.
        doi:10.1115/1.2824120.
-    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and 
-       Correlations for Convection Heat Transfer and Pressure Losses in 
+    .. [2] El-Genk, Mohamed S., and Timothy M. Schriener. "A Review and
+       Correlations for Convection Heat Transfer and Pressure Losses in
        Toroidal and Helically Coiled Tubes." Heat Transfer Engineering 0, no. 0
        (June 7, 2016): 1-28. doi:10.1080/01457632.2016.1194693.
-    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat 
-       Transfer Coefficient in Helical Coils with Single Phase Flow." 
-       International Journal of Heat and Mass Transfer 89 (October 2015): 
+    .. [3] Hardik, B. K., P. K. Baburajan, and S. V. Prabhu. "Local Heat
+       Transfer Coefficient in Helical Coils with Single Phase Flow."
+       International Journal of Heat and Mass Transfer 89 (October 2015):
        522-38. doi:10.1016/j.ijheatmasstransfer.2015.05.069.
     '''
     return 0.00619*Re**0.92*Pr**0.4*(1. + 3.455*Di/Dc)
@@ -1756,19 +1839,19 @@ def helical_turbulent_Nu_Xin_Ebadian(Re, Pr, Di, Dc):
 def Nu_laminar_rectangular_Shan_London(a_r):
     r'''Calculates internal convection Nusselt number for laminar flows
     in a rectangular pipe of varying aspect ratio, as developed in [1]_.
-    
+
     This model is derived assuming a constant wall heat flux from all sides.
     This is entirely theoretically derived and reproduced experimentally.
 
     .. math::
         Nu_{lam} = 8.235\left(1 - 2.0421\alpha + 3.0853\alpha^2
         - 2.4765\alpha^3 + 1.0578\alpha^4 - 0.1861\alpha^5\right)
-    
+
     Parameters
     ----------
     a_r : float
         The aspect ratio of the channel, from 0 to 1 [-]
-        
+
     Returns
     -------
     Nu : float
@@ -1777,26 +1860,26 @@ def Nu_laminar_rectangular_Shan_London(a_r):
     Notes
     -----
     At an aspect ratio of 1 (square channel), the Nusselt number converges to
-    3.610224. The authors of [1]_ also published [2]_, which tabulates in 
-    their table 42 some less precise results that are used to check this 
+    3.610224. The authors of [1]_ also published [2]_, which tabulates in
+    their table 42 some less precise results that are used to check this
     function.
-    
+
     Examples
     --------
     >>> Nu_laminar_rectangular_Shan_London(.7)
     3.751762675455
-    
+
     References
     ----------
-    .. [1] Shah, R. K, and Alexander Louis London. Supplement 1: Laminar Flow 
-       Forced Convection in Ducts: A Source Book for Compact Heat Exchanger 
+    .. [1] Shah, R. K, and Alexander Louis London. Supplement 1: Laminar Flow
+       Forced Convection in Ducts: A Source Book for Compact Heat Exchanger
        Analytical Data. New York: Academic Press, 1978.
-    .. [2] Shah, Ramesh K., and A. L. London. "Laminar Flow Forced Convection 
+    .. [2] Shah, Ramesh K., and A. L. London. "Laminar Flow Forced Convection
        Heat Transfer and Flow Friction in Straight and Curved Ducts - A Summary
-       of Analytical Solutions." STANFORD UNIV CA DEPT OF MECHANICAL 
-       ENGINEERING, STANFORD UNIV CA DEPT OF MECHANICAL ENGINEERING, November 
+       of Analytical Solutions." STANFORD UNIV CA DEPT OF MECHANICAL
+       ENGINEERING, STANFORD UNIV CA DEPT OF MECHANICAL ENGINEERING, November
        1971. http://www.dtic.mil/docs/citations/AD0736260.
     '''
-    return 8.235*(1 - 2.0421*a_r + 3.0853*a_r**2 - 2.4765*a_r**3 
+    return 8.235*(1 - 2.0421*a_r + 3.0853*a_r**2 - 2.4765*a_r**3
                   + 1.0578*a_r**4 - 0.1861*a_r**5)
 
